module Data.Aviation.Casa.AbbreviationsAndAcronyms where

data Source =
  AIP
  | AIS
  | ATA
  | ATSB
  | CAR1988
  | CAR1998
  | CASA
  | CASR1998
  | CASRPart String
  | FAR
  | ICAO (Maybe String)
  | JAA
  | OBPR
  | ORR
  | WATOG
  | OtherSource String
  deriving (Eq, Ord, Show)

newtype Sources =
  Sources
    [Source]
  deriving (Eq, Ord, Show)

data Acronym =
  Acronym
    String
    String -- Meaning
    Sources
  deriving (Eq, Ord, Show)  

newtype Acronyms =
  Acronyms
    [Acronym]
  deriving (Eq, Ord, Show)

acronyms ::
  Acronyms
acronyms =
  Acronyms
    [
      Acronym "...T" "Bearing (true)" (Sources [AIS])
    , Acronym "A" "Amber" (Sources [ICAO Nothing])
    , Acronym "A/A" "Air to air" (Sources [AIS])
    , Acronym "A/G" "Air-to-ground" (Sources [AIS])
    , Acronym "AAA" "Amended meterological message" (Sources [ICAO Nothing])
    , Acronym "AAAA" "Aerial Application Association of Australia" (Sources [])
    , Acronym "AAC" "Airworthiness Advisory Circular" (Sources [CAR1988])
    , Acronym "AACC" "Area approach control centre" (Sources [AIS])
    , Acronym "AAD" "Assigned altitude deviation" (Sources [AIS])
    , Acronym "AAIM" "Aircraft Autonomous Integrity Monitor" (Sources [])
    , Acronym "AAIS" "Automatic aerodrome information service" (Sources [AIS])
    , Acronym "AAL" "Above aerodrome level" (Sources [AIS])
    , Acronym "AAR" "Authorised Airworthiness Representative" (Sources [CASRPart "183"])
    , Acronym "AAT" "Administrative Appeals Tribunal" (Sources [])
    , Acronym "ABAA" "Amateur Built Aircraft Acceptance" (Sources [CASRPart "21"])
    , Acronym "ABAS" "Aircraft Based Augmentation System" (Sources [])
    , Acronym "ABF" "Australian Ballooning Federation" (Sources [])
    , Acronym "ABI" "Advance boundary information" (Sources [AIS])
    , Acronym "ABM" "Abeam" (Sources [AIS])
    , Acronym "ABN" "Aerodrome beacon" (Sources [AIS])
    , Acronym "ABT" "About" (Sources [AIS])
    , Acronym "ABV" "Above..." (Sources [AIS])
    , Acronym "AC" "Advisory Circular" (Sources [CASR1998])
    , Acronym "AC" "Altocumulus (met)" (Sources [ICAO Nothing,AIP])
    , Acronym "ACA" "Australian Commonwealth Authority" (Sources [])
    , Acronym "ACARS" "Aircraft communication addressing and reporting system (pronounced 'AY-CARS')" (Sources [AIS])
    , Acronym "ACAS" "Airborne Collision Avoidance System" (Sources [CAR1988])
    , Acronym "ACC" "Area control centre" (Sources [AIS])
    , Acronym "ACCID" "Initial notification of an aircraft accident" (Sources [AIS])
    , Acronym "ACD" "Airways clearance delivery" (Sources [AIS])
    , Acronym "ACFT" "Aircraft" (Sources [AIS])
    , Acronym "ACJ-XXX" "Advisory Circular Joint (issued by the JAA, can be followed by a country code)" (Sources [JAA])
    , Acronym "ACK" "Acknowledge" (Sources [AIS])
    , Acronym "ACL" "Altimeter check location" (Sources [ICAO Nothing])
    , Acronym "ACN" "Aircraft classification number" (Sources [ICAO Nothing])
    , Acronym "ACN" "Australian company number" (Sources [])
    , Acronym "ACPT" "Accept, accepted" (Sources [AIS])
    , Acronym "ACROB" "Acrobatics" (Sources [])
    , Acronym "Act" "the Civil Aviation Act 1988" (Sources [])
    , Acronym "ACT" "Active, activated, activity" (Sources [AIS])
    , Acronym "AD" "Aerodrome" (Sources [ICAO Nothing,AIP])
    , Acronym "AD" "Airworthiness Directive" (Sources [CASRPart "39"])
    , Acronym "ADA" "Advisory area" (Sources [ICAO Nothing])
    , Acronym "ADAO" "Authorised Design Approval Organisation" (Sources [CASRPart "146"])
    , Acronym "ADC" "Aerodrome chart" (Sources [AIS])
    , Acronym "ADDGM" "Aerodrome diagrams" (Sources [AIS])
    , Acronym "ADDN" "Addition, additional" (Sources [AIS])
    , Acronym "ADF" "Automatic Direction Finding (equipment)" (Sources [AIS])
    , Acronym "ADF" "Australian Defence Force" (Sources [])
    , Acronym "ADIZ" "Air Defence Identification Zone" (Sources [ICAO Nothing,AIS])
    , Acronym "ADJ" "Adjacent" (Sources [AIS])
    , Acronym "ADO" "Aerodrome office" (Sources [ICAO Nothing])
    , Acronym "ADQ" "Adequate aerodrome" (Sources [AIS])
    , Acronym "ADR" "Advisory route" (Sources [])
    , Acronym "ADS" "The address (when this abbreviation is used to request a repetition, the question (IMI) precedes the abbreviation, eg IMI ADS) (to be used in AFS as a procedure signal)" (Sources [ICAO Nothing,AIP])
    , Acronym "ADS" "Automatic Dependent Surveillance" (Sources [AIP,ICAO Nothing])
    , Acronym "ADS-B" "Automatic Dependent Surveillance - Broadcast" (Sources [AIP])
    , Acronym "ADS-C" "Automatic Dependent Surveillance - Contract" (Sources [AIP])
    , Acronym "ADSU" "Automatic Dependent Surveillance Unit" (Sources [ICAO Nothing])
    , Acronym "ADZ" "Advise" (Sources [AIS])
    , Acronym "AEB" "CASA's Airworthiness Engineering Branch" (Sources [CASA])
    , Acronym "AEP" "Aerodrome emergency plan" (Sources [AIS])
    , Acronym "AER" "Authorised Engineering Representative" (Sources [CASRPart "183"])
    , Acronym "AERIS" "Automatic en route information service" (Sources [AIS])
    , Acronym "AFAP" "Australian Federation of Air Pilots" (Sources [])
    , Acronym "AFCS" "Automatic flight control system" (Sources [ICAO Nothing])
    , Acronym "AFIL" "Flight notification: - filed in the air, or - indicating the position at which ATS services will first be required" (Sources [AIS])
    , Acronym "AFIS" "Aerodrome flight information service" (Sources [ICAO Nothing,AIP])
    , Acronym "AFM" "Aircraft Flight Manual" (Sources [CAR1988])
    , Acronym "AFM" "Yes, affirm, affirmative, that is correct" (Sources [AIS])
    , Acronym "AFRU" "Aerodrome Frequency Response Unit (also known as a \"beepback\" unit)" (Sources [AIS])
    , Acronym "AFS" "Aeronautical fixed service" (Sources [ICAO Nothing,AIP])
    , Acronym "AFT" "After" (Sources [AIS])
    , Acronym "AFTN" "Aeronautical fixed telecommunication network" (Sources [ICAO Nothing])
    , Acronym "AFZ" "Australian fishing zone(s)" (Sources [AIS])
    , Acronym "Ag" "Agriculture" (Sources [])
    , Acronym "AGA" "Again" (Sources [ICAO Nothing])
    , Acronym "AGD" "Attorney-General's Department" (Sources [])
    , Acronym "AGL" "Above Ground Level" (Sources [ICAO Nothing,AIP])
    , Acronym "AH" "Artificial Horizon" (Sources [])
    , Acronym "AH" "After hours" (Sources [AIS])
    , Acronym "AIC" "Aeronautical Information Circular" (Sources [AIP])
    , Acronym "AIDC" "Air traffic services inter-facitility data communications" (Sources [ICAO Nothing])
    , Acronym "AIP" "Aeronautical Information Publication" (Sources [ICAO Nothing,AIP])
    , Acronym "AIP ENR" "Aeronautical Information Publication En-route" (Sources [])
    , Acronym "AIP ERSA" "Aeronautical Information Publication En-route Supplement Australia" (Sources [])
    , Acronym "AIP GEN" "Aeronautical Information Publication General" (Sources [])
    , Acronym "AIRAC" "Aeronautical Information Regulation and Control" (Sources [ICAO Nothing,AIP])
    , Acronym "AIRC" "Aeronautical Information and Control" (Sources [ICAO Nothing])
    , Acronym "AIREP" "Air-Report" (Sources [AIP,ICAO Nothing])
    , Acronym "AIRMET" "Information in plain language concerning weather significant to light aircraft operations at or below 10,000FT" (Sources [AIS])
    , Acronym "AIS" "Aeronautical Information Service" (Sources [AIP])
    , Acronym "AL" "Approach Lights" (Sources [AIS])
    , Acronym "ALA" "Aircraft Landing Area" (Sources [AIP])
    , Acronym "ALA" "Alighting area" (Sources [ICAO Nothing])
    , Acronym "ALA/HLS" "Aircraft Landing Area/Helicopter Landing Site" (Sources [])
    , Acronym "ALAEA" "Australian Licensed Aircraft Engineers Association" (Sources [])
    , Acronym "ALARP" "As Low as Reasonably Practical" (Sources [AIS])
    , Acronym "ALERFA" "Alert phase" (Sources [AIS])
    , Acronym "ALI" "Airworthiness Limitation Item" (Sources [])
    , Acronym "ALM" "Aircraft Landing Minima" (Sources [AIS])
    , Acronym "ALR" "Alerting Message" (Sources [AIS])
    , Acronym "ALRS" "Approach lighting system" (Sources [ICAO Nothing])
    , Acronym "ALS" "Approach Lighting System" (Sources [AIS])
    , Acronym "ALT" "Altitude" (Sources [AIS])
    , Acronym "ALTN" "Alternate, Alternating (light alternates in colour)" (Sources [AIS])
    , Acronym "ALTN" "Alternate (aerodrome)" (Sources [AIS])
    , Acronym "AMA" "Area minimum altitude" (Sources [ICAO Nothing])
    , Acronym "AMC" "Acceptable Means of Compliance" (Sources [])
    , Acronym "AMD" "Amend, Amended" (Sources [AIS])
    , Acronym "AMDT" "Amendment (AIP amendment)" (Sources [ICAO Nothing,AIP])
    , Acronym "AME" "Aircraft Maintenance Engineer" (Sources [CASRPart "66"])
    , Acronym "AMM" "Aircraft Maintenance Manual" (Sources [WATOG])
    , Acronym "AMO" "Approved Maintenance Organisation" (Sources [CASRPart "145"])
    , Acronym "AMP" "Aircraft Maintenance Program" (Sources [CASRPart "145"])
    , Acronym "AMPA" "Authorised Maintenance Personnel Assessor" (Sources [CASRPart "66"])
    , Acronym "AMRD" "Australian Maintenance Requirements Document" (Sources [CASRPart "43"])
    , Acronym "AMS" "Aircraft Maintenance Specialist" (Sources [CASRPart "145"])
    , Acronym "AMSA" "Australian Maritime Safety Authority" (Sources [])
    , Acronym "AMSL" "Above Mean Sea Level" (Sources [AIS])
    , Acronym "AMSS" "Aeronautical mobile satellite service" (Sources [ICAO Nothing])
    , Acronym "AMT" "Aircraft Maintenance Technician" (Sources [CASRPart "66"])
    , Acronym "ANA" "Air Navigation Act" (Sources [])
    , Acronym "ANC" "Aeronautical Chart 1:50,000 (followed by name/title)" (Sources [AIS])
    , Acronym "ANCS" "Aeronautical navigation chart - small scale (followed by name/title and scale)" (Sources [ICAO Nothing])
    , Acronym "ANO" "Air Navigation Order" (Sources [])
    , Acronym "ANS" "Answer" (Sources [ICAO Nothing])
    , Acronym "ANTA" "Australian National Training Authority" (Sources [CASRPart "66"])
    , Acronym "ANVIS" "Aviator Night Vision Imaging Systems" (Sources [])
    , Acronym "AO" "Air Operator" (Sources [])
    , Acronym "AOC" "Air Operators Certificate" (Sources [CASRPart "119"])
    , Acronym "AOC" "Aerodrome Obstacle Chart (followed by name/title)" (Sources [AIS,AIP])
    , Acronym "AOCM" "Air Operators Certification Manual" (Sources [])
    , Acronym "AOD" "Alcohol and Other Drug" (Sources [CASA])
    , Acronym "AOG" "Aircraft On Ground" (Sources [WATOG])
    , Acronym "AOPA" "Aircraft Owners and Pilots Association" (Sources [])
    , Acronym "AP" "Airport" (Sources [AIS])
    , Acronym "APAPI" "Abbreviated Precision Approach Path Indicator (pronounced 'AY-PAPI')" (Sources [AIS])
    , Acronym "APCH" "Approach" (Sources [AIS])
    , Acronym "APDC" "Aircraft Parking/Docking Chart (followed by name/title)" (Sources [AIS])
    , Acronym "APF" "Australian Parachute Federation" (Sources [])
    , Acronym "APMA" "Australian Parts Manufacturer Approval" (Sources [CASRPart "21"])
    , Acronym "APN" "Apron" (Sources [ICAO Nothing,AIP])
    , Acronym "APP" "Approach Control" (Sources [AIS])
    , Acronym "APRX" "Approximate, Approximately" (Sources [AIS])
    , Acronym "APSG" "After Passing" (Sources [AIS])
    , Acronym "APU" "Auxillary power unit" (Sources [ICAO Nothing])
    , Acronym "APV" "Approach with Vertical Guidance" (Sources [])
    , Acronym "APV" "Approve, Approved, Approval" (Sources [AIS])
    , Acronym "AQZ" "Area QNH Zone" (Sources [AIS])
    , Acronym "ARC" "Area Chart" (Sources [ICAO Nothing,AIP])
    , Acronym "ARFFS" "Aerodrome Rescue and Fire Fighting Service (sometimes referred to as RFFS)" (Sources [CASRPart "139"])
    , Acronym "ARFL" "Aeroplane Reference Field Length" (Sources [AIS])
    , Acronym "ARFO" "Area Forecast" (Sources [])
    , Acronym "ARH" "Aircraft Registration Holder" (Sources [CASRPart "47"])
    , Acronym "ARM" "Airspace Risk Model" (Sources [ICAO Nothing,CASA])
    , Acronym "ARM" "Aircraft Recovery Manual" (Sources [WATOG])
    , Acronym "ARN" "Aviation Reference Number" (Sources [CASA,AIP])
    , Acronym "ARNG" "Arrange" (Sources [AIS])
    , Acronym "ARO" "Air traffic services reporting office" (Sources [ICAO Nothing])
    , Acronym "ARP" "Aerodrome reference point" (Sources [ICAO Nothing,AIP])
    , Acronym "ARP" "Air-Report (message type designator)" (Sources [ICAO Nothing,AIP])
    , Acronym "ARQ" "Automatic error correction" (Sources [ICAO Nothing])
    , Acronym "ARR" "Arrive, Arrival" (Sources [AIS])
    , Acronym "ARS" "Special Air-Report (message type designator)" (Sources [AIS])
    , Acronym "ARST" "Arresting (specify (part of) aircraft arresting equipment)" (Sources [ICAO Nothing])
    , Acronym "AS" "Altostratus (meteorological)" (Sources [ICAO Nothing,AIP])
    , Acronym "AS" "Australian Standard" (Sources [])
    , Acronym "ASA" "Australian Skydiving Association" (Sources [])
    , Acronym "ASAC" "Australian Sports Aviation Confederation" (Sources [])
    , Acronym "ASAP" "As Soon as Possible" (Sources [AIS])
    , Acronym "ASC" "Ascend to or ascending" (Sources [ICAO Nothing])
    , Acronym "ASDA" "Accelerate-stop distance available" (Sources [ICAO Nothing])
    , Acronym "ASE" "Airborne Support Equipment" (Sources [WATOG])
    , Acronym "ASE" "Altimetry System Error" (Sources [ICAO Nothing,AIP])
    , Acronym "ASEPTA" "Approved Single-engine Turbine Aeroplane" (Sources [])
    , Acronym "ASF" "Aviation Safety Forum" (Sources [AIS])
    , Acronym "ASH" "Aviation Services Handbook" (Sources [])
    , Acronym "ASI" "Air Speed Indicatort" (Sources [])
    , Acronym "ASI" "Aviation Safety Index" (Sources [])
    , Acronym "ASIR" "Aviation Safety Incident Report" (Sources [])
    , Acronym "ASPH" "Asphalt" (Sources [ICAO Nothing])
    , Acronym "ASR" "Area Surveillance Radar" (Sources [AIS])
    , Acronym "ASRA" "Australian Sport Rotorcraft Association" (Sources [])
    , Acronym "ASSI" "Air Safety Support International- a wholly-owned subsidiary of the UK Civil Aviation Authority" (Sources [OtherSource "Air Safety Support International (UK)"])
    , Acronym "ASTM" "American Society for Testing Materials" (Sources [])
    , Acronym "ASTRA" "Australian Strategic Air Traffic Management Group" (Sources [])
    , Acronym "AT-VASIS" "Abbreviated 'T' Visual Approach Slope Indicator System (pronounced 'AY-TEE-VASIS')" (Sources [AIS])
    , Acronym "AT..." "At (followed by time at which weather change is forecast to occur)" (Sources [ICAO Nothing])
    , Acronym "ATA" "Actual Time of Arrival" (Sources [AIS])
    , Acronym "ATA" "Air Transport Association" (Sources [])
    , Acronym "ATC" "Air Traffic Control (in general)" (Sources [ICAO Nothing,AIP])
    , Acronym "ATD" "Actual Time of Departure" (Sources [AIS])
    , Acronym "ATE" "Automatic Test Equipment" (Sources [WATOG])
    , Acronym "ATEL/ANAV" "Aeronautical Telecommunication and Radio Navigation Services" (Sources [CASRPart "171"])
    , Acronym "ATFM" "Air Traffic Flow Management" (Sources [AIS])
    , Acronym "ATIS" "Automatic terminal information service" (Sources [ICAO Nothing])
    , Acronym "ATM" "Air traffic management" (Sources [ICAO Nothing,AIP])
    , Acronym "ATN" "Aeronautical telecommunications network" (Sources [ICAO Nothing])
    , Acronym "ATO" "Aviation Testing Officer" (Sources [])
    , Acronym "ATP" "At.. (time or place)" (Sources [ICAO Nothing])
    , Acronym "ATPL" "Airline Transport Pilot Licence" (Sources [])
    , Acronym "ATS" "Air Traffic Service(s)" (Sources [])
    , Acronym "ATSB" "Australian Transport Safety Bureau" (Sources [])
    , Acronym "ATSO" "Australian Technical Standard Order" (Sources [CASRPart "21"])
    , Acronym "ATSOA" "Australian Technical Standard Order Authorisation" (Sources [CASRPart "21"])
    , Acronym "ATTN" "Attention" (Sources [AIS])
    , Acronym "ATZ" "Aerodrome traffic zone" (Sources [ICAO Nothing])
    , Acronym "AUF" "Australian Ultralight Federation (now Recreational Aviation Australia)" (Sources [])
    , Acronym "AUTH" "Authorised, Authorisation" (Sources [AIS])
    , Acronym "AUW" "All Up Weight" (Sources [AIS])
    , Acronym "AUX" "Auxiliary" (Sources [AIS])
    , Acronym "AVBL" "Available" (Sources [AIS])
    , Acronym "AVG" "Average" (Sources [AIS])
    , Acronym "AVGAS" "Aviation Gasoline" (Sources [AIS])
    , Acronym "AVM" "Abrupt Vertical Manoeuvres (by the MIL)" (Sources [AIS])
    , Acronym "AWB" "Airworthiness Bulletin" (Sources [])
    , Acronym "AWIB" "Aerodrome Weather Information Broadcast" (Sources [AIS])
    , Acronym "AWK" "Aerial Work (Air work - general aviation)" (Sources [AIS])
    , Acronym "AWS" "Automatic Weather Station" (Sources [AIS])
    , Acronym "AWTA" "Advise as to what time is available" (Sources [ICAO Nothing])
    , Acronym "AWY" "Airway" (Sources [ICAO Nothing,AIP])
    , Acronym "AZM" "Azimuth" (Sources [ICAO Nothing,AIP])
    , Acronym "B" "Blue" (Sources [ICAO Nothing,AIP])
    , Acronym "BA" "Braking action" (Sources [ICAO Nothing])
    , Acronym "BASA" "Bilateral Aviation Safety Agreement" (Sources [])
    , Acronym "BASE" "Cloud Base (met)" (Sources [AIS])
    , Acronym "BCFG" "Fog Patches (met)" (Sources [AIS])
    , Acronym "BCN" "Beacon (aeronautical ground light)" (Sources [AIS])
    , Acronym "BCST" "Broadcast" (Sources [AIS])
    , Acronym "BDRY" "Boundary" (Sources [AIS])
    , Acronym "BECMG" "Becoming" (Sources [AIS])
    , Acronym "BETA" "Manually controlled mode for constant speed propellers or turbo prop aircraft" (Sources [])
    , Acronym "BFR" "Before" (Sources [AIS])
    , Acronym "BIP-M" "Basic Instruction Package for Meteorologists" (Sources [])
    , Acronym "BIPMT" "Basic Instruction Package for Meteorological Technicians" (Sources [])
    , Acronym "BITE" "Built In Test Equipment" (Sources [WATOG])
    , Acronym "BKN" "Broken (cloud descriptor) (met)" (Sources [AIS])
    , Acronym "BL..." "Blowing (followed by DU=dust, SA=sand or SN=snow)" (Sources [AIS])
    , Acronym "BLDG" "Building" (Sources [AIS])
    , Acronym "BLO" "Below Clouds" (Sources [AIS])
    , Acronym "BLW" "Below" (Sources [AIS])
    , Acronym "BOM" "Bureau of Meteorology" (Sources [AIS])
    , Acronym "BOMB" "Bombing" (Sources [AIS])
    , Acronym "BR" "Mist" (Sources [AIS])
    , Acronym "BRF" "Short (used to indicate type of approach)" (Sources [AIS])
    , Acronym "BRG" "Bearing" (Sources [AIS])
    , Acronym "BRKG" "Braking" (Sources [AIS])
    , Acronym "BRW" "Brakes release weight" (Sources [])
    , Acronym "BS" "Broadcasting Station (Commercial)" (Sources [AIS])
    , Acronym "BTL" "Between Layers" (Sources [AIS])
    , Acronym "BTN" "Between" (Sources [AIS])
    , Acronym "C" "Degrees Celsius (Centigrade)" (Sources [AIS])
    , Acronym "C" "Centre (Runway)" (Sources [AIS])
    , Acronym "CA" "Course Acquisition" (Sources [])
    , Acronym "CA/GRO" "Certified Air/Ground Radio Operator" (Sources [CASRPart "139"])
    , Acronym "CA/GRS" "Certified Air/Ground Radio Service" (Sources [CASRPart "171"])
    , Acronym "CAA NZ" "Civil Aviation Authority New Zealand" (Sources [])
    , Acronym "CAAP" "Civil Aviation Advisory Publication" (Sources [CAR1988])
    , Acronym "CAGRO" "Certified Air Ground Radio Operation" (Sources [AIP])
    , Acronym "CAMO" "Certified Airworthiness Management Organisation" (Sources [])
    , Acronym "CAMP" "Continuous Airworthiness Maintenance Program" (Sources [CASRPart "145"])
    , Acronym "CAO" "Civil Aviation Order" (Sources [])
    , Acronym "CAR" "Civil Aviation Regulations 1988" (Sources [])
    , Acronym "CAS" "Calibrated air speed" (Sources [ICAO Nothing])
    , Acronym "CASA" "Civil Aviation Safety Authority" (Sources [])
    , Acronym "CASR" "Civil Aviation Safety Regulations 1998" (Sources [])
    , Acronym "CAT" "Category" (Sources [AIS])
    , Acronym "CAT" "Clear Air Turbulence" (Sources [AIS])
    , Acronym "CAVOK" "Visibility, cloud and present weather better than prescribed values or conditions" (Sources [AIS])
    , Acronym "CB" "Cumulonimbus (met)" (Sources [AIS])
    , Acronym "CBT" "Competency-based Training" (Sources [])
    , Acronym "CC" "Cirrocumulus (met)" (Sources [AIS])
    , Acronym "CCA" "Corrected meteorological message (for CCB, CCC..etc., in sequence) (message type designator)" (Sources [ICAO Nothing])
    , Acronym "CCF" "Capability Check Flight" (Sources [])
    , Acronym "CCTS" "Circuits" (Sources [AIS])
    , Acronym "CD" "Candela" (Sources [ICAO Nothing])
    , Acronym "CDCCL" "Critical Design Configuration Control Limit" (Sources [])
    , Acronym "CDI" "Course Direction Indicator" (Sources [])
    , Acronym "CDL" "Configuration Deviation List" (Sources [CASRPart "43"])
    , Acronym "CDN" "Coordination (message type designator)" (Sources [ICAO Nothing])
    , Acronym "CEN" "En Route and Area ATC unit" (Sources [AIS])
    , Acronym "CEO" "Chief Executive Officer" (Sources [])
    , Acronym "CET" "Clearance Expiry Time" (Sources [AIS])
    , Acronym "CF" "Change Frequency to" (Sources [AIS])
    , Acronym "CFI" "Chief Flying Instructor" (Sources [CAR1988])
    , Acronym "CFIT" "Controlled Flight into Terrain" (Sources [])
    , Acronym "CFL" "Cleared Flight Level" (Sources [AIS])
    , Acronym "CFM" "Confirm, I confirm" (Sources [AIS])
    , Acronym "CG" "Centre of gravity" (Sources [ICAO Nothing])
    , Acronym "CGL" "Circling guidance light(s)" (Sources [ICAO Nothing])
    , Acronym "CH" "This is a channel continuity check of transmission to permit comparision of your record of channel-sequence numbers of messages received on the channel (<em>to be used in AFS as a procedure signal)</em>" (Sources [ICAO Nothing])
    , Acronym "CHG" "Modification (message type designator)" (Sources [ICAO Nothing])
    , Acronym "CHTR" "Charter" (Sources [AIS])
    , Acronym "CI" "Cirrus (met)" (Sources [AIS])
    , Acronym "CIDIN" "Common ICAO data interchange network" (Sources [ICAO Nothing])
    , Acronym "CIR" "Command Instrument Rating" (Sources [CAR1988])
    , Acronym "CIT" "Near, Over Large Town(s)" (Sources [AIS])
    , Acronym "CIV" "Civil" (Sources [AIS])
    , Acronym "CK" "Check" (Sources [AIS])
    , Acronym "CL" "Centre Line" (Sources [AIS])
    , Acronym "CLA" "Clear type of ice formation" (Sources [AIS])
    , Acronym "CLBR" "Calibration" (Sources [AIS])
    , Acronym "CLD" "Cloud (met)" (Sources [AIS])
    , Acronym "CLG" "Calling" (Sources [AIS])
    , Acronym "CLIAS" "Climbing Indicated Airspeed" (Sources [AIS])
    , Acronym "CLMAX" "Maximum Co-efficient of Lift" (Sources [])
    , Acronym "CLR" "Clear, Cleared to... Clearance" (Sources [AIS])
    , Acronym "CLSD" "Closed, Close, Closing" (Sources [AIS])
    , Acronym "CM (cm)" "Centimetre" (Sources [AIS])
    , Acronym "CMB" "Climb to or Climbing to" (Sources [AIS])
    , Acronym "CMM" "Component Maintenance Manual" (Sources [WATOG])
    , Acronym "CMPL" "Configuration, Maintenance and Procedures" (Sources [])
    , Acronym "CMPL" "Completion, Completed, or Complete" (Sources [AIS])
    , Acronym "CMR" "Certification Maintenance Requirements" (Sources [])
    , Acronym "CMSD" "Commissioned" (Sources [AIS])
    , Acronym "CNL" "Cancel" (Sources [AIS])
    , Acronym "CNL" "Flight plan cancellation message" (Sources [AIS])
    , Acronym "CNS" "Communications, Navigation and Surveillance" (Sources [AIS])
    , Acronym "COA" "Certificates of Approval (issued to maintenance organisations)" (Sources [CAR1988])
    , Acronym "CofA" "Certificate of Airworthiness" (Sources [CAR1988])
    , Acronym "COM" "Communications" (Sources [AIS])
    , Acronym "CONC" "Concrete" (Sources [AIS])
    , Acronym "COND" "Condition" (Sources [AIS])
    , Acronym "CONS" "Continuous" (Sources [AIS])
    , Acronym "CONST" "Construction, Constructed" (Sources [AIS])
    , Acronym "CONT" "Continue(s), Continued" (Sources [AIS])
    , Acronym "COOR" "Coordinate, Coordinated" (Sources [AIS])
    , Acronym "COORD" "Coordinates" (Sources [AIS])
    , Acronym "COP" "Change over point" (Sources [ICAO Nothing])
    , Acronym "CoR" "Certificate of Registration" (Sources [CAR1988])
    , Acronym "COR" "Correct, Corrected, Correction" (Sources [AIS])
    , Acronym "COS" "Conical Surface" (Sources [AIS])
    , Acronym "COT" "At the Coast, Coastal" (Sources [AIS])
    , Acronym "COV" "Cover, Covered, Covering" (Sources [AIS])
    , Acronym "CP" "Chief Pilot" (Sources [CAR1988])
    , Acronym "CPDLC" "Controller-Pilot Data Link Communication</td />" (Sources [ICAO Nothing,AIP])
    , Acronym "CPL" "Commercial Pilot Licence" (Sources [CAR1988])
    , Acronym "CPL" "Current flight plan" (Sources [ICAO Nothing])
    , Acronym "CRC" "Cyclic redundancy check" (Sources [ICAO Nothing])
    , Acronym "CRIS" "Cost Recovery Impact Statement" (Sources [OtherSource "Department of Finance"])
    , Acronym "CRM" "Crew Resource Management" (Sources [CASRPart "121"])
    , Acronym "CRZ" "Cruise" (Sources [AIS])
    , Acronym "CS" "Cirrostratus (met)" (Sources [AIS])
    , Acronym "CS" "Call sign" (Sources [AIS])
    , Acronym "CSDD" "Common Support Data Dictionary published by the Air Transport Association of America (ATA). The CSDD replaces the WATOG." (Sources [])
    , Acronym "CSU" "Constant Speed Unit" (Sources [])
    , Acronym "CTA" "Control Area" (Sources [AIS])
    , Acronym "CTAF" "Common Traffic Advisory Frequency" (Sources [CASRPart "172",AIP])
    , Acronym "CTAF(R)" "Common Traffic Advisory Frequency - (Radio)" (Sources [AIS])
    , Acronym "CTAM" "Climb to and maintain" (Sources [ICAO Nothing])
    , Acronym "CTC" "Category Technical Competency" (Sources [CAR1988])
    , Acronym "CTC" "Contact" (Sources [ICAO Nothing,AIP])
    , Acronym "CTL" "Control" (Sources [AIS])
    , Acronym "CTN" "Caution" (Sources [AIS])
    , Acronym "CTR" "Control Zone" (Sources [AIP])
    , Acronym "CU" "Cumulus (met)" (Sources [AIS])
    , Acronym "CUF" "Cumuliform (met)" (Sources [AIS])
    , Acronym "CUST" "Customs" (Sources [AIS])
    , Acronym "CVR" "Cockpit voice recorder" (Sources [ICAO Nothing,AIP])
    , Acronym "CW" "Carrier Wave" (Sources [ICAO Nothing])
    , Acronym "CWY" "Clearway" (Sources [AIS])
    , Acronym "D" "Deleted" (Sources [AIS])
    , Acronym "D" "Downward (tendency in RVR (Runway visual range) during previous 10 minutes)" (Sources [ICAO Nothing])
    , Acronym "D-ATIS" "Data Link Automatic Terminal Information Service (pronounced'DEE-ATIS')</td />" (Sources [AIS])
    , Acronym "D-VOLMET" "Data Link VOLMET </td />" (Sources [AIS])
    , Acronym "D..." "Danger Area (followed by identification)" (Sources [AIS])
    , Acronym "DA" "Decision Altitude" (Sources [AIS])
    , Acronym "DA/H" "Decision Altitude/Height" (Sources [AIP])
    , Acronym "DALR" "Dry Adiabatic Lapse Rate" (Sources [])
    , Acronym "DAME" "Designated Aviation Medical Examiner" (Sources [CASRPart "67"])
    , Acronym "DAO" "Designated Aviation Ophthamologist" (Sources [CASRPart "67"])
    , Acronym "DAP" "Departure and Approach Procedures" (Sources [AIP])
    , Acronym "DCD" "Double channel duplex" (Sources [ICAO Nothing])
    , Acronym "DCKG" "Docking" (Sources [AIS])
    , Acronym "DCMSD" "Decommissioned" (Sources [AIS])
    , Acronym "DCPC" "Direct Controller-Pilot Communications" (Sources [AIS])
    , Acronym "DCS" "Double channel simplex" (Sources [ICAO Nothing])
    , Acronym "DCT" "Direct (in relation to flight plan clearances and type of approach)" (Sources [AIS])
    , Acronym "DE" "Form (used to preceed the call sign of the calling station) (to be used in AFS as a procedure signal)</em>" (Sources [ICAO Nothing,AIP])
    , Acronym "DEC" "December" (Sources [AIS])
    , Acronym "DEG" "Degrees" (Sources [AIS])
    , Acronym "DEP" "Depart, Departure, Departed, Departing, Departure Message" (Sources [AIS])
    , Acronym "DER" "Departure End of Runway" (Sources [AIP])
    , Acronym "DER" "Designated Engineering Representative" (Sources [FAR])
    , Acronym "DES" "Descend to, Descending to" (Sources [AIS])
    , Acronym "DEST" "Destination" (Sources [AIS])
    , Acronym "DETRESFA" "Distress Phase" (Sources [AIS])
    , Acronym "DEV" "Deviation, Deviating" (Sources [AIS])
    , Acronym "DF" "Direction Finder/ Finding" (Sources [AIS])
    , Acronym "DFDR" "Digital Flight Data Recorder" (Sources [AIS])
    , Acronym "DFTI" "Distance from touchdown indicator" (Sources [ICAO Nothing])
    , Acronym "DGA" "Distance Measuring Equipment or Global Positioning Satellite System Arrival" (Sources [])
    , Acronym "DH" "Decision Height" (Sources [ICAO Nothing])
    , Acronym "DIF" "Diffuse" (Sources [AIS])
    , Acronym "DISP" "Displaced" (Sources [AIS])
    , Acronym "DIST" "Distance" (Sources [AIS])
    , Acronym "DIV" "Diversion, Divert, Diverting" (Sources [AIS])
    , Acronym "DLA" "Delay (message type designator)" (Sources [ICAO Nothing,AIP])
    , Acronym "DLIC" "Data Link Initiation Capability" (Sources [AIS])
    , Acronym "DLY" "Daily" (Sources [AIS])
    , Acronym "DMC" "Direct Maintenance Cost" (Sources [WATOG])
    , Acronym "DME" "Distance Measuring Equipment" (Sources [ICAO Nothing,AIP])
    , Acronym "DMEN" "DME (International)" (Sources [AIS])
    , Acronym "DMEP" "DME (International Precision used in conjunction with Microwave Landing System)" (Sources [AIS])
    , Acronym "DNG" "Danger, Dangerous" (Sources [AIS])
    , Acronym "DOC" "Direct Operating Cost" (Sources [WATOG])
    , Acronym "DOC" "Documents" (Sources [AIS])
    , Acronym "DoD" "Department of Defence" (Sources [])
    , Acronym "DOM" "Domestic" (Sources [AIS])
    , Acronym "DP" "Dew Point Temperature" (Sources [ICAO Nothing,AIP])
    , Acronym "DP" "Discussion Paper" (Sources [CASA])
    , Acronym "DPT" "Depth" (Sources [AIS])
    , Acronym "DR" "Dead Reckoning (navigation)" (Sources [ICAO Nothing])
    , Acronym "DR..." "Low drifting (followed by DU=dust, SA=sand or SN=snow)" (Sources [AIS])
    , Acronym "DRG" "During" (Sources [AIS])
    , Acronym "DS" "Dust storm" (Sources [AIS])
    , Acronym "DSB" "Double sideband" (Sources [ICAO Nothing])
    , Acronym "DTAM" "Descend to And Maintain" (Sources [AIS])
    , Acronym "DTG" "Date-Time Group" (Sources [AIS])
    , Acronym "DTHR" "Displaced Runway Threshold" (Sources [AIS])
    , Acronym "DTRT" "Deteriorate, Deteriorating" (Sources [AIS])
    , Acronym "DTW" "Dual tandem wheels" (Sources [ICAO Nothing])
    , Acronym "DU" "Dust" (Sources [AIS])
    , Acronym "DUC" "Dense Upper Cloud (met)" (Sources [AIS])
    , Acronym "DUPE" "This is a duplicate message <em>(to be used in Aeronautical Fixed Service as a procedure signal)</em>" (Sources [ICAO Nothing])
    , Acronym "DUR" "Duration" (Sources [AIS])
    , Acronym "DVOR" "Doppler VOR" (Sources [AIS])
    , Acronym "DW" "Dual wheels" (Sources [ICAO Nothing])
    , Acronym "DZ" "Drizzle" (Sources [AIS])
    , Acronym "E" "East, East Longitude" (Sources [AIS])
    , Acronym "E &nbsp;E &nbsp;E" "Error <em>(to be used in AFS as a procedure signal)</em>" (Sources [ICAO Nothing])
    , Acronym "EASA" "European Aviaton Safety Agency" (Sources [])
    , Acronym "EAT" "Expected Approach Time" (Sources [AIS])
    , Acronym "EB" "Eastbound" (Sources [AIS])
    , Acronym "ECAR" "European Civil Aviation Requirement (formerly JAR)" (Sources [])
    , Acronym "EDTO" "Extended Diversion Time Operations" (Sources [])
    , Acronym "EET" "Estimated Elapsed Time" (Sources [AIS])
    , Acronym "EFB" "Electronic Flight Bag" (Sources [])
    , Acronym "EFC" "Expect further clearance" (Sources [ICAO Nothing])
    , Acronym "EGNOS" "European Geostationary Navigation Overlay System" (Sources [])
    , Acronym "EGPWS" "Enhanced Ground Proximity Warning System" (Sources [CAR1988])
    , Acronym "EHF" "Extremely high frequency (30,000 to 300,000 MHz)" (Sources [ICAO Nothing,AIP])
    , Acronym "EHR" "Encumbrance Holder Register" (Sources [CASRPart "47"])
    , Acronym "ELBA" "Emergency locator beacon-aircraft" (Sources [ICAO Nothing])
    , Acronym "ELEV" "Elevation" (Sources [AIS])
    , Acronym "ELR" "Extra Long Range" (Sources [AIS])
    , Acronym "ELT(S)" "Emergency Locator Transmitter (Survival)" (Sources [CAR1988])
    , Acronym "EM" "Engine Manual" (Sources [WATOG])
    , Acronym "EM" "Explanatory Memorandum (submitted to EXCO with regulation amendment)" (Sources [])
    , Acronym "EM" "Emission" (Sources [AIS])
    , Acronym "EMBD" "Embedded in a Layer (to indicate cumulonimbus embedded in layers of other clouds)" (Sources [AIS])
    , Acronym "EMERG" "Emergency" (Sources [AIS])
    , Acronym "EMS" "Emergency Medical Service" (Sources [])
    , Acronym "EMS" "Environment Management System" (Sources [])
    , Acronym "END" "Stop-end (related to RVR)" (Sources [ICAO Nothing])
    , Acronym "ENDCE" "Endurance" (Sources [AIS])
    , Acronym "ENE" "East North-East" (Sources [AIS])
    , Acronym "ENG" "Engine" (Sources [AIS])
    , Acronym "ENR" "En Route" (Sources [AIS])
    , Acronym "ENRC" "En Route Chart (followed by name/title)" (Sources [AIS])
    , Acronym "EOBT" "Estimated off Blocks Time" (Sources [AIS])
    , Acronym "EPA" "Environment Protection Agency" (Sources [])
    , Acronym "EPIRB" "Electronic Position Indicating Radio Beacon (marine term.)" (Sources [AIS])
    , Acronym "EQPT" "Equipment" (Sources [AIS])
    , Acronym "ER" "Here..<em>or</em> herewith" (Sources [ICAO Nothing])
    , Acronym "ERC" "En-route Chart" (Sources [AIS])
    , Acronym "ERP" "Emergency Response Plan" (Sources [])
    , Acronym "ERSA" "En-route Supplement Australia" (Sources [AIP])
    , Acronym "ES" "Explanatory Statement (tabled with regulations in Parliament)" (Sources [])
    , Acronym "ESD" "Electrostatic sensitive discharge" (Sources [])
    , Acronym "ESDE" "ESD equipment" (Sources [])
    , Acronym "ESE" "East Southeast" (Sources [AIS])
    , Acronym "ESIR" "Electronic safety incident report" (Sources [])
    , Acronym "EST" "Estimate or estimated or estimate (message type designator)" (Sources [AIS])
    , Acronym "ETA" "Estimated Time of Arrival, Estimating Arrival" (Sources [AIS])
    , Acronym "ETCM" "Engine trend and condition monitoring" (Sources [])
    , Acronym "ETD" "Estimated Time of Departure, Estimating Departure" (Sources [AIS])
    , Acronym "ETO" "Estimated Time Over significant point" (Sources [AIS])
    , Acronym "ETOPS" "Extended range operations by turbine-engined aeroplanes" (Sources [ICAO Nothing])
    , Acronym "ETP" "Equi Time Interval" (Sources [])
    , Acronym "ETT" "Estimated Time Interval" (Sources [])
    , Acronym "EV" "Every" (Sources [AIS])
    , Acronym "EVU" "Enforceable Voluntary Undertaking" (Sources [OtherSource "Civil Aviation Act 1988"])
    , Acronym "EXC" "Except" (Sources [AIS])
    , Acronym "EXCO" "Executive Council" (Sources [])
    , Acronym "EXER" "Exercises, Exercising, to exercise" (Sources [AIS])
    , Acronym "EXP" "Expect, Expected, Expecting" (Sources [AIS])
    , Acronym "EXTD" "Extend, Extending, Extended" (Sources [AIS])
    , Acronym "F" "Fixed (chart symbol)" (Sources [AIS])
    , Acronym "FAA" "Federal Aviation Administration of the USA" (Sources [])
    , Acronym "FAAOC" "Foreign Aircraft Air Operator's Certificate" (Sources [CASRPart "129"])
    , Acronym "FAC" "Facility, Facilities" (Sources [AIS])
    , Acronym "FADEC" "Full Authority Digital Engine Control" (Sources [])
    , Acronym "FAF" "Final Approach Fix" (Sources [AIP,ICAO Nothing])
    , Acronym "FAL" "Facilitation of International Air" (Sources [AIS])
    , Acronym "FAP" "Final Approach Point" (Sources [AIP,ICAO Nothing])
    , Acronym "FARs" "Federal Aviation Regulations (Federal Aviation Administration of the USA)" (Sources [])
    , Acronym "FATO" "Final approach and take-off area" (Sources [ICAO Nothing,AIP])
    , Acronym "FAWP" "Final Approach Waypoint" (Sources [AIS])
    , Acronym "FAX" "Facsimile Transmission" (Sources [AIS])
    , Acronym "FBL" "Light (used to indicate the intensity of WX phenomena, interference or static reports, eg BL RA = light rain)" (Sources [AIS])
    , Acronym "FC" "Funnel Cloud (tornado or water spout)" (Sources [AIS])
    , Acronym "FCST" "Forecast" (Sources [AIS])
    , Acronym "FCT" "Friction coefficient" (Sources [ICAO Nothing])
    , Acronym "FD" "Fault Detection" (Sources [])
    , Acronym "FDE" "Fault detection and exclusion (in relation to GPS equipment)" (Sources [])
    , Acronym "FDL" "Fixed Distance Lighting" (Sources [AIS])
    , Acronym "FDPS" "Flight Data Processing system" (Sources [AIS])
    , Acronym "FDS" "Flight Director System" (Sources [])
    , Acronym "FEW" "Few (cloud descriptor)" (Sources [AIS])
    , Acronym "FFR" "Flood, Fire Relief" (Sources [AIS])
    , Acronym "FG" "Fog" (Sources [AIS])
    , Acronym "FIA" "Flight Information Area" (Sources [AIS])
    , Acronym "FIC" "Flight Information Centre" (Sources [AIS])
    , Acronym "FIO" "Flight Information Office" (Sources [AIS])
    , Acronym "FIR" "Flight Information Region" (Sources [ICAO Nothing,AIP])
    , Acronym "FISA" "Flight information service (automated)" (Sources [ICAO Nothing])
    , Acronym "FISS" "Flight Information Service Station" (Sources [AIS])
    , Acronym "FIX" "Fault Isolation Manual" (Sources [WATOG])
    , Acronym "FL" "Flight Level" (Sources [ICAO Nothing,AIP])
    , Acronym "FLD" "Field" (Sources [AIS])
    , Acronym "FLG" "Flashing" (Sources [AIS])
    , Acronym "FLIR" "Forward Looking Infra Red" (Sources [])
    , Acronym "FLR" "Flares" (Sources [AIS])
    , Acronym "FLT" "Flight" (Sources [ICAO Nothing,WATOG,AIP])
    , Acronym "FLTCK" "Flight check" (Sources [ICAO Nothing,AIP])
    , Acronym "FLUC" "Fluctuating, Fluctuation, Fluctuated" (Sources [AIS])
    , Acronym "FLW" "Follow(s), Following" (Sources [AIS])
    , Acronym "FLY" "Fly, Flying" (Sources [AIS])
    , Acronym "FM" "From" (Sources [AIS])
    , Acronym "FM..." "From (followed by time weather change is forecast to begin)" (Sources [AIS])
    , Acronym "FMS" "Flight Management System" (Sources [ICAO Nothing])
    , Acronym "FMU" "Flow Management Unit" (Sources [AIS])
    , Acronym "FNA" "Final Approach" (Sources [AIS])
    , Acronym "FNPT" "Flight and Navigation Procedures Trainer" (Sources [ICAO Nothing])
    , Acronym "FOD" "Foreign Object Damage" (Sources [WATOG])
    , Acronym "FOI" "Flying Operations Inspector" (Sources [])
    , Acronym "FPD" "Flight Plan Designator" (Sources [AIS])
    , Acronym "FPL" "Filed Flight Plan Message" (Sources [AIS])
    , Acronym "FPM" "Feet per Minute" (Sources [AIS])
    , Acronym "FPR" "Flight Plan Route" (Sources [AIS])
    , Acronym "FR" "Fuel Remaining" (Sources [AIS])
    , Acronym "FREQ" "Frequency" (Sources [AIS])
    , Acronym "FRM" "Fault Reporting Manual" (Sources [WATOG])
    , Acronym "FRMS" "Fatigue Risk Management System" (Sources [])
    , Acronym "FRNG" "Firing" (Sources [AIS])
    , Acronym "FRONT" "Front (relating to weather)" (Sources [ICAO Nothing])
    , Acronym "FRQ" "Frequent" (Sources [AIS])
    , Acronym "FS" "Flight Service (in general)" (Sources [AIS])
    , Acronym "FSA" "Flight Safety Australia" (Sources [])
    , Acronym "FSL" "Full Stop Landing" (Sources [AIS])
    , Acronym "FSP" "Fish Spotting" (Sources [AIS])
    , Acronym "FSS" "Flight service station" (Sources [ICAO Nothing])
    , Acronym "FST" "First" (Sources [AIS])
    , Acronym "FT" "Feet" (Sources [AIS])
    , Acronym "FTD" "Flight training device" (Sources [CASRPart "60"])
    , Acronym "FTE" "Full time equivalent" (Sources [])
    , Acronym "FTO" "Flight Training Organisation" (Sources [])
    , Acronym "FU" "Smoke" (Sources [AIS])
    , Acronym "FXD" "Fixed" (Sources [AIS])
    , Acronym "FZ" "Freezing" (Sources [AIS])
    , Acronym "FZDZ" "Freezing Drizzle" (Sources [AIS])
    , Acronym "FZFG" "Freezing Fog" (Sources [AIS])
    , Acronym "FZL" "Freezing Level" (Sources [AIS])
    , Acronym "FZRA" "Freezing Rain" (Sources [AIS])
    , Acronym "G" "Gravity" (Sources [])
    , Acronym "G" "Green" (Sources [AIS])
    , Acronym "G/A" "Ground-to-air" (Sources [ICAO Nothing])
    , Acronym "G/A/G" "Ground-to-air and air-to-ground" (Sources [ICAO Nothing])
    , Acronym "GA" "Go ahead, resume sending (to be used in AFS as a procedure signal)" (Sources [ICAO Nothing])
    , Acronym "GA" "General Aviation" (Sources [CAR1988])
    , Acronym "GAAP" "General Aviation Aerodrome Procedures" (Sources [AIS])
    , Acronym "GAMET" "Area forecast for low-level flights" (Sources [ICAO Nothing])
    , Acronym "GAPAN" "Honourable Company of Air Pilots, Australia, Inc." (Sources [])
    , Acronym "GBAS" "Ground Based Augmentation System" (Sources [])
    , Acronym "GCA" "Ground Controlled Approach" (Sources [AIS])
    , Acronym "GCN" "General Computing Network (operated by Airservices Australia)" (Sources [AIS])
    , Acronym "GDOP" "Geometric Dilution of Precision" (Sources [])
    , Acronym "GEN" "General" (Sources [AIS])
    , Acronym "GEO" "Geographic, true" (Sources [AIS])
    , Acronym "GES" "Ground Earth Station" (Sources [AIS])
    , Acronym "GFA" "The Gliding Federation of Australia" (Sources [])
    , Acronym "GFY" "Glider Flying" (Sources [AIS])
    , Acronym "GHA" "Ground handling agents" (Sources [])
    , Acronym "GIVD" "Gravity Induced Vestibular Dysfunction" (Sources [])
    , Acronym "GLD" "Glider" (Sources [AIS])
    , Acronym "GLOC" "Gravity Induced Loss of Consciousness" (Sources [])
    , Acronym "GLONASS" "Global Orbiting Navigation Satellite System (pronounced 'GLO-NAS')" (Sources [AIS])
    , Acronym "GM" "Guidance Material" (Sources [])
    , Acronym "GMC" "Ground Movement Chart (followed by name/title)" (Sources [AIS])
    , Acronym "GND" "Ground" (Sources [AIS])
    , Acronym "GNDCK" "Ground Check" (Sources [AIS])
    , Acronym "GNS" "Global Navigation System" (Sources [AIS])
    , Acronym "GNSS" "Global navigation satellite system" (Sources [ICAO Nothing,AIP])
    , Acronym "GP" "Guiding principles" (Sources [CAR1998])
    , Acronym "GP" "Glide Path" (Sources [ICAO Nothing,AIP])
    , Acronym "GP" "FLG Group Flashing (number) (used in conjunction with aerodrome lighting)" (Sources [AIS])
    , Acronym "GPI" "Glide Path Intercept" (Sources [AIS])
    , Acronym "GPS Global positioning system (see GNSS)\nGPWS" "Ground proximity warning system" (Sources [])
    , Acronym "GR" "Hail" (Sources [AIS])
    , Acronym "GRAD" "Minimum Required Climb Gradient" (Sources [AIS])
    , Acronym "GRAS" "Ground Based Regional Augmentation System" (Sources [])
    , Acronym "GRASS" "Grass Landing Area" (Sources [AIS])
    , Acronym "GRIB" "Processed meteoroglogical data in the form of grid point values expressed in binary form <em>(aeronautical meterological code)</em>" (Sources [ICAO Nothing,AIP])
    , Acronym "GRVL" "Gravel" (Sources [AIS])
    , Acronym "GS" "Groundspeed" (Sources [AIS])
    , Acronym "GS" "Small Hail and/or Snow Pellets" (Sources [AIS])
    , Acronym "GSE" "Ground Support Equipment" (Sources [WATOG])
    , Acronym "GUND" "Geoid Undulation" (Sources [AIS])
    , Acronym "H24" "Continuous day and night service" (Sources [AIS])
    , Acronym "HAA" "Height Above Aerodrome" (Sources [AIS])
    , Acronym "HAA" "Helicopter Association of Australia" (Sources [])
    , Acronym "HAAMC" "Head of Aircraft Airworthiness and Maintenance Control" (Sources [OtherSource "Aviation Law in Australia, 2004 edition"])
    , Acronym "HAM" "Head of Aircraft Maintenance" (Sources [CASRPart "145"])
    , Acronym "HAMC" "Head of Aircraft Maintenance Control" (Sources [CASRPart "145"])
    , Acronym "HAPI" "Helicopter approach path indicator" (Sources [ICAO Nothing])
    , Acronym "HAT" "Height Above Threshold" (Sources [AIS])
    , Acronym "HBN" "Hazard Beacon" (Sources [AIS])
    , Acronym "HDF" "High frequency direction-finding station" (Sources [ICAO Nothing])
    , Acronym "HDG" "Heading" (Sources [AIS])
    , Acronym "HDS" "Hours of Daylight Saving" (Sources [AIS])
    , Acronym "HEL" "Helicopter" (Sources [AIS])
    , Acronym "HF" "Human Factors" (Sources [])
    , Acronym "HF" "High Frequency (3000 to 30,000 KHZ)" (Sources [AIS])
    , Acronym "HFEM" "Human Factor and Error Management System" (Sources [])
    , Acronym "HGFA" "Hang Gliding Federation of Australia Inc" (Sources [])
    , Acronym "HGS" "Heads-up Guidance System" (Sources [])
    , Acronym "HGT" "Height, Height Above" (Sources [AIS])
    , Acronym "HIAL" "High Intensity Approach Lighting" (Sources [AIS])
    , Acronym "HIOL" "High Intensity Obstacle Lights" (Sources [AIS])
    , Acronym "HIRL" "High Intensity Runway Lighting" (Sources [AIS])
    , Acronym "HJ" "Sunrise to Sunset" (Sources [AIS])
    , Acronym "HLDG" "Holding" (Sources [AIS])
    , Acronym "HLS" "Helicopter Landing Site" (Sources [AIS])
    , Acronym "HMI" "Human-machine Interface" (Sources [])
    , Acronym "HN" "Sunset to Sunrise" (Sources [AIS])
    , Acronym "HO" "Service available to meet operational requirements" (Sources [AIS])
    , Acronym "HOFO" "Head of Flying Operations" (Sources [])
    , Acronym "HOSP" "Hospital Aircraft" (Sources [])
    , Acronym "HOTAS" "Head of Training and Standards" (Sources [AIS])
    , Acronym "HOTC" "Head of Training and Checking" (Sources [])
    , Acronym "HP" "Horse Power" (Sources [])
    , Acronym "HPA" "HectoPascal" (Sources [])
    , Acronym "HR" "Hours" (Sources [AIS])
    , Acronym "HS" "Homestead" (Sources [AIS])
    , Acronym "HS" "Service available during hours of scheduled operations" (Sources [AIS])
    , Acronym "HSL" "Hold Short Lights" (Sources [AIS])
    , Acronym "HUD" "Head Up Display" (Sources [AIS])
    , Acronym "HURCN" "Hurricane" (Sources [])
    , Acronym "HVDF" "High and very high frequency direction finding stations <em>(at the same location)</em>" (Sources [AIS])
    , Acronym "HVY" "Heavy" (Sources [AIS])
    , Acronym "HVY" "Heavy (used to indicate the intensity of WX phenomena, eg HVY RA = heavy rain)" (Sources [AIS])
    , Acronym "HX" "No specific working hours" (Sources [AIS])
    , Acronym "HYR" "Higher" (Sources [AIS])
    , Acronym "HZ" "Haze" (Sources [AIS])
    , Acronym "HZ (hz)" "Hertz" (Sources [AIS])
    , Acronym "HZS" "Horizontal Surface" (Sources [AIS])
    , Acronym "IA" "Inspection authorisation" (Sources [AIS])
    , Acronym "IAC" "Instrument approach chart <em>(followed by name/title)</em>" (Sources [FAR])
    , Acronym "IAF" "Initial Approach Fix" (Sources [ICAO Nothing,AIP])
    , Acronym "IAL" "Instrument Approach and Landing Chart" (Sources [AIS])
    , Acronym "IAO" "In and out of clouds" (Sources [AIS])
    , Acronym "IAP" "Instrument Approach Plate" (Sources [AIS])
    , Acronym "IAR" "Intersection of air routes" (Sources [])
    , Acronym "IAS" "Indicated air speed" (Sources [ICAO Nothing])
    , Acronym "IATA" "International Air Transport Association" (Sources [ICAO Nothing])
    , Acronym "IAW" "In Accordance With" (Sources [])
    , Acronym "IAWP" "Initial Approach Way-point" (Sources [])
    , Acronym "IBN" "Identification Beacon" (Sources [AIS])
    , Acronym "IC" "Ice Crystals (MET code)" (Sources [AIS])
    , Acronym "ICA" "Instructions for continuing airworthiness (issued by manufacturer or designer)" (Sources [AIS])
    , Acronym "ICAO" "International Civil Aviation Organization" (Sources [CAR1998])
    , Acronym "ICE" "Icing, Ice" (Sources [ICAO Nothing])
    , Acronym "ICUS" "In-command Under Supervision" (Sources [AIS])
    , Acronym "ID" "Identifier, identify" (Sources [])
    , Acronym "IDENT" "Identification" (Sources [AIS])
    , Acronym "IF" "Instrument Flight" (Sources [AIS])
    , Acronym "IF" "Intermediate Approach Fix" (Sources [])
    , Acronym "IFF" "Identification Friend/Foe" (Sources [AIS])
    , Acronym "IFR" "Instrument flight rules" (Sources [AIS])
    , Acronym "IFSD" "In-flight Shutdown" (Sources [ICAO Nothing,AIP])
    , Acronym "IG" "Implementation Group" (Sources [])
    , Acronym "IGA" "International general aviation" (Sources [])
    , Acronym "ILS" "Instrument Landing System" (Sources [ICAO Nothing,AIP])
    , Acronym "IM" "Inner Marker" (Sources [AIS])
    , Acronym "IMC" "Instrument meteorological conditions (other than VMC)" (Sources [AIS])
    , Acronym "IMC" "Indirect Maintenance Cost" (Sources [CAR1988])
    , Acronym "IMG" "Immigration" (Sources [WATOG])
    , Acronym "IMI" "Interrogation sign" (Sources [AIS])
    , Acronym "IMPR" "Improve, Improving, Improvement" (Sources [ICAO Nothing])
    , Acronym "IMT" "Immediate, Immediately" (Sources [AIS])
    , Acronym "INA" "Initial approach" (Sources [AIS])
    , Acronym "INBD" "Inbound" (Sources [ICAO Nothing])
    , Acronym "INC" "In Cloud" (Sources [AIS])
    , Acronym "INCERFA" "Uncertainty Phase" (Sources [AIS])
    , Acronym "INFO" "Information" (Sources [AIS])
    , Acronym "INOP" "Inoperative" (Sources [AIS])
    , Acronym "INP" "If not possible" (Sources [AIS])
    , Acronym "INPR" "In progress" (Sources [ICAO Nothing])
    , Acronym "INS" "Inertial Navigation System" (Sources [ICAO Nothing])
    , Acronym "INSTL" "Install, Installed, Installation" (Sources [AIS])
    , Acronym "INSTR" "Instrument" (Sources [AIS])
    , Acronym "INT" "Intersection" (Sources [AIS])
    , Acronym "INTER" "Intermittent, Intermittently (meteorological)" (Sources [AIS])
    , Acronym "INTL" "International" (Sources [AIS])
    , Acronym "INTRG" "Interrogator" (Sources [AIS])
    , Acronym "INTRP" "Interrupt, Interruption, Interrupted" (Sources [AIS])
    , Acronym "INTSF" "Intensify, Intensifying" (Sources [AIS])
    , Acronym "INTST" "Intensity" (Sources [AIS])
    , Acronym "IoA" "Instrument of appointment" (Sources [AIS])
    , Acronym "IOC" "Indirect Operating Cost" (Sources [CAR1988])
    , Acronym "IOE" "Initial Operational Experience" (Sources [WATOG])
    , Acronym "IPC" "Illustrated Parts Catalogue" (Sources [])
    , Acronym "IR" "Ice on runway" (Sources [WATOG])
    , Acronym "IREX" "Instrument Training Examination" (Sources [ICAO Nothing])
    , Acronym "IRM" "Immediately Reportable Matters" (Sources [ATSB])
    , Acronym "IRS" "Internal Reporting System" (Sources [])
    , Acronym "ISA" "International Standard Atmosphere" (Sources [])
    , Acronym "ISB" "Independent Sideband" (Sources [AIS])
    , Acronym "ISIM" "Integrated Safety Investigation Methodology" (Sources [CASA])
    , Acronym "ISO9000" "International Organization for Standardization" (Sources [])
    , Acronym "ISOL" "Isolated" (Sources [])
    , Acronym "ITT" "Interstage Turbine Temperature" (Sources [AIS])
    , Acronym "IWI" "Illuminated Wind Indicator" (Sources [])
    , Acronym "IWP" "Intermediate Way-point" (Sources [AIS])
    , Acronym "J-BAR" "Jet Barrier" (Sources [AIS])
    , Acronym "JAA" "Joint Aviation Authorities (of Europe)" (Sources [AIS])
    , Acronym "JAR" "Joint Aviation Requirements (of the European JAA)" (Sources [])
    , Acronym "JAR-OPS" "JAR Operations" (Sources [AIS])
    , Acronym "JTSO" "Joint Technical Standard Order" (Sources [AIS])
    , Acronym "JTST" "Jet Stream" (Sources [AIS])
    , Acronym "KDR" "Knowledge Deficiency Report" (Sources [AIS])
    , Acronym "KG (kg)" "Kilograms" (Sources [AIS])
    , Acronym "KHZ (kHz)" "Kilohertz" (Sources [])
    , Acronym "KM (km)" "Kilometers" (Sources [AIS])
    , Acronym "KMH (km/h)" "Kilometers per hour" (Sources [AIS])
    , Acronym "KPA (kPa)" "Kilopascals" (Sources [AIS])
    , Acronym "KT (kt)" "Knots" (Sources [AIS])
    , Acronym "KW (kw)" "Kilowatts" (Sources [AIS])
    , Acronym "L" "Left (runway identification)" (Sources [AIS])
    , Acronym "L" "Locator (see LM, LO)" (Sources [AIS])
    , Acronym "LAAS" "Local Area Augmentation System" (Sources [AIS])
    , Acronym "LAHSO" "Land and Hold Short Operations" (Sources [AIS])
    , Acronym "LAME" "Licensed Aircraft Maintenance Engineer" (Sources [])
    , Acronym "LAN" "Inland" (Sources [AIS])
    , Acronym "LAT" "Latitude" (Sources [CASRPart "66"])
    , Acronym "LDA" "Landing distance available" (Sources [AIS])
    , Acronym "LDG" "Landing" (Sources [AIS])
    , Acronym "LDI" "Landing Direction Indicator" (Sources [ICAO Nothing,AIP])
    , Acronym "LDP" "Landing decision point" (Sources [AIS])
    , Acronym "LEN" "Length" (Sources [AIS])
    , Acronym "LF" "Low Frequency (30 to 300 KHZ)" (Sources [ICAO Nothing])
    , Acronym "LGT" "Light, Lighting" (Sources [AIS])
    , Acronym "LGTD" "Lighted" (Sources [AIS])
    , Acronym "LIH" "Light Intensity High" (Sources [AIS])
    , Acronym "LIL" "Light Intensity Low" (Sources [AIS])
    , Acronym "LIM" "Light Intensity Medium" (Sources [AIS])
    , Acronym "LIOL" "Low Intensity Obstacle Lights" (Sources [AIS])
    , Acronym "LIRL" "Low Intensity Runway Lights" (Sources [AIS])
    , Acronym "LJR" "Low Jet Route" (Sources [AIS])
    , Acronym "LL" "Lower Limit" (Sources [AIS])
    , Acronym "LLN" "Low-level Navigation (by the MIL)" (Sources [AIS])
    , Acronym "LLO" "Low Level Operations (by the MIL)" (Sources [AIS])
    , Acronym "LLZ" "Localizer" (Sources [AIS])
    , Acronym "LM" "Locator (middle)" (Sources [AIS])
    , Acronym "LMT" "Local mean time" (Sources [AIS])
    , Acronym "LO" "Locator (outer)" (Sources [AIS])
    , Acronym "LOC" "Locally, Location, Located, Local" (Sources [AIS])
    , Acronym "LOE" "Lane of Entry" (Sources [AIS])
    , Acronym "LONG" "Longitude" (Sources [AIS])
    , Acronym "LOSA" "Line Operations Safety Audit" (Sources [AIS])
    , Acronym "LPT" "Liquid Penetrant Test" (Sources [AIS])
    , Acronym "LRCS" "Long-range communication system" (Sources [])
    , Acronym "LRG" "Long Range" (Sources [])
    , Acronym "LRI" "Line Replaceable Item" (Sources [FAR])
    , Acronym "LRNS" "Long-range navigation system" (Sources [AIS])
    , Acronym "LRU" "Line Replaceable Unit" (Sources [WATOG])
    , Acronym "LSA" "Light Sport Aircraft" (Sources [FAR])
    , Acronym "LSALT" "Lowest safe altitude" (Sources [WATOG])
    , Acronym "LSd" "CASA's Legal Services Division" (Sources [])
    , Acronym "LTD" "Limited" (Sources [])
    , Acronym "LUL" "Lowest Usable Level" (Sources [CASA])
    , Acronym "LV" "Light and Variable (relating to wind)" (Sources [AIS])
    , Acronym "LVE" "Leave, Leaving" (Sources [AIS])
    , Acronym "LVL" "Level" (Sources [AIS])
    , Acronym "LYR" "Layer, Layered" (Sources [AIS])
    , Acronym "M" "Mach number (followed by figures ie .02 = Mach .02)" (Sources [AIS])
    , Acronym "M (m)" "Metres (preceded by figures)" (Sources [AIS])
    , Acronym "M/E" "Multi-engine" (Sources [AIS])
    , Acronym "MAAT" "Manual Authoring and Assessment Tool" (Sources [CASA])
    , Acronym "MAE" "Men and Equipment" (Sources [])
    , Acronym "MAG" "Magnetic" (Sources [])
    , Acronym "MAHWP" "Missed Approach Holding Way-point" (Sources [AIS])
    , Acronym "MAINT" "Maintenance" (Sources [AIS])
    , Acronym "MAN" "Manual" (Sources [AIS])
    , Acronym "MAP" "Aeronautical Maps and Charts" (Sources [AIS])
    , Acronym "MAP" "Manifold Air Pressure" (Sources [AIS])
    , Acronym "MAPT" "Missed Approach Point" (Sources [AIS])
    , Acronym "MAR" "At Sea" (Sources [])
    , Acronym "MAUW" "Maximum All Up Weight" (Sources [AIS])
    , Acronym "MAWP" "Missed Approach Waypoint" (Sources [AIS])
    , Acronym "MAX" "Maximum" (Sources [])
    , Acronym "MBST" "Microburst" (Sources [AIS])
    , Acronym "MBZ" "Mandatory Broadcast Zone" (Sources [AIS])
    , Acronym "MCC" "Multi-crew Co-ordination" (Sources [AIP])
    , Acronym "MCM" "Maintenance control manual" (Sources [CASA])
    , Acronym "MCQFS" "Manual of criteria for the qualification of flight simulators ICAO Doc 9625-AN/938" (Sources [])
    , Acronym "MCUR" "Mean Cycles Between Unscheduled Removals" (Sources [CASRPart "145"])
    , Acronym "MCW" "Modulated Continuous Wave" (Sources [CASRPart "60"])
    , Acronym "MDA" "Minimum Descent Altitude" (Sources [WATOG])
    , Acronym "MDF" "Medium Frequency Direction Finding Station" (Sources [AIS])
    , Acronym "MDR" "Major Defect Report" (Sources [AIS])
    , Acronym "MEA" "Minimum En-route Altitude" (Sources [AIS])
    , Acronym "MED" "Medical" (Sources [CAR1988])
    , Acronym "MEL" "Minimum equipment list" (Sources [AIS])
    , Acronym "MERSITAB" "Manufacturing, Engineering and Related Services Industry Training Advisory Body" (Sources [AIS])
    , Acronym "MET" "Meteorological, Meteorology" (Sources [ICAO Nothing])
    , Acronym "MET" "REPORT Aviation routine weather report" (Sources [CASRPart "66"])
    , Acronym "METAR" "Aviation routine weather report (in aeronautical meteorological code)" (Sources [AIS])
    , Acronym "METRAD" "MET Radar" (Sources [AIS])
    , Acronym "MF" "Medium Frequency (300 to 3000 KHZ)" (Sources [AIS])
    , Acronym "MHZ (mhz)" "Megahertz" (Sources [AIS])
    , Acronym "MIFG" "Shallow Fog" (Sources [AIS])
    , Acronym "MIL" "Military" (Sources [AIS])
    , Acronym "MIL-STD" "Military Standard" (Sources [AIS])
    , Acronym "MIN" "Minutes" (Sources [AIS])
    , Acronym "MIOL" "Medium Intensity Obstacle Lights" (Sources [])
    , Acronym "MIRL" "Medium Intensity Runway Lights" (Sources [AIS])
    , Acronym "MISC" "Miscellaneous" (Sources [AIS])
    , Acronym "MKR" "Marker Radio Beacon" (Sources [AIS])
    , Acronym "MLJ" "Military Low Jet" (Sources [AIS])
    , Acronym "MLJR" "Military Low Jet Route" (Sources [AIS])
    , Acronym "MLS" "Microwave Landing System" (Sources [AIS])
    , Acronym "MLW" "Maximum Landing Weight" (Sources [AIS])
    , Acronym "MM" "Middle Marker" (Sources [AIS])
    , Acronym "MMEL" "Master minimum equipment list" (Sources [AIS])
    , Acronym "MNM" "Minimum" (Sources [AIS])
    , Acronym "MNT" "Monitor, Monitoring," (Sources [ICAO Nothing])
    , Acronym "MNTN" "Maintain, Maintained, Maintaining" (Sources [AIS])
    , Acronym "MOA" "Military Operating Area" (Sources [AIS])
    , Acronym "MOC" "Minimum obstacle clearance (required)" (Sources [AIS])
    , Acronym "MOD" "Moderate, Moderately" (Sources [AIS])
    , Acronym "MOD" "Moderate (used to indicate the intensity of WX phenomena, interference or static reports, eg MOD RA = moderate rain)." (Sources [ICAO Nothing,AIP])
    , Acronym "MON" "Above Mountains" (Sources [AIS])
    , Acronym "MOPS" "Minimum Operational Performance Standards" (Sources [AIS])
    , Acronym "MOS" "Manual of Standards" (Sources [AIS])
    , Acronym "MOU" "Memorandum of understanding" (Sources [AIS])
    , Acronym "MOV" "Move, Moved, Moving, Movement" (Sources [CAR1998])
    , Acronym "MOWP" "Method of Working Plan" (Sources [])
    , Acronym "MPD" "Maintenance Planning Data" (Sources [AIS])
    , Acronym "MPI" "Magnetic Particle Inspection" (Sources [AIS])
    , Acronym "MPL" "Multi-crew Pilot Licence" (Sources [ATA,FAR])
    , Acronym "MPS" "Metres per Second" (Sources [])
    , Acronym "MPT" "Magnetic Particle Inspection Technician" (Sources [ICAO (Just "Annex 1 'Personnel Licensing'")])
    , Acronym "MRB" "Maintenance Review Board" (Sources [AIS])
    , Acronym "MRBR" "Maintenance Review Board Report" (Sources [])
    , Acronym "MRG" "Medium Range" (Sources [ATA,FAR])
    , Acronym "MRO" "Maintenance, repair and overhaul" (Sources [])
    , Acronym "MRP" "ATS/MET Reporting Point" (Sources [AIS])
    , Acronym "MS" "Minus" (Sources [CASRPart "145"])
    , Acronym "MSA" "Minimum sector altitude" (Sources [AIS])
    , Acronym "MSAS" "Multi-function Transport Satellite (MTSAT) Satellite-based Augmentation System" (Sources [AIS])
    , Acronym "MSDS" "Material Safety Data Sheets" (Sources [AIP])
    , Acronym "MSG" "Message" (Sources [])
    , Acronym "MSG" "Maintenance Steering Group" (Sources [])
    , Acronym "MSG-3" "Maintenance Steering Group Logic Process" (Sources [AIS])
    , Acronym "MSI" "Maintenance Significant Item" (Sources [ATA,FAR])
    , Acronym "MSL" "Mean Sea Level" (Sources [])
    , Acronym "MSOS" "Maintenance specific operation specification" (Sources [WATOG])
    , Acronym "MSSR" "Monopulse Secondary Surveillance Radar" (Sources [AIS])
    , Acronym "MT" "Mountain" (Sources [CASRPart "145"])
    , Acronym "MTBF" "Mean Time Between Failure" (Sources [AIS])
    , Acronym "MTBR" "Mean Time Between Removals" (Sources [AIS])
    , Acronym "MTBUR" "Mean Time Between Unscheduled Removals" (Sources [WATOG])
    , Acronym "MTO" "Maintenance training organisation" (Sources [WATOG])
    , Acronym "MTOW" "Maximum take-off weight" (Sources [WATOG])
    , Acronym "MTP" "Maximum Tyre Pressure" (Sources [CASRPart "147"])
    , Acronym "MTSAT" "Multi-function Transport Satellite" (Sources [AIP])
    , Acronym "MTTF" "Mean Time To Failure" (Sources [AIS])
    , Acronym "MTTR" "Mean Time To Repair" (Sources [])
    , Acronym "MTTUR" "Mean Time To Unscheduled Removal" (Sources [WATOG])
    , Acronym "MTUR" "Special Term For Data Transmittal" (Sources [WATOG])
    , Acronym "MTW" "Mountain waves" (Sources [WATOG])
    , Acronym "MVA" "Minimum Vector Altitude" (Sources [WATOG])
    , Acronym "MWO" "Meteorological Watch Office" (Sources [AIS])
    , Acronym "MX" "Mixed type of ice formation (white and clear)" (Sources [AIS])
    , Acronym "N" "North, North Latitude" (Sources [AIS])
    , Acronym "N1" "Gas Generator Speed" (Sources [AIS])
    , Acronym "N2" "Second Stage Turbine Speed" (Sources [AIS])
    , Acronym "NAA" "National Airworthiness Authority (for a country other than Australia)" (Sources [])
    , Acronym "NAD" "Non-acqueous Developer" (Sources [])
    , Acronym "NAIPS" "National aeronautical information processing system" (Sources [CAR1998])
    , Acronym "NANDTB" "National Aerospace Non-destructive Testing Board" (Sources [])
    , Acronym "NANU" "Notice Advisory to NavStar Users" (Sources [AIP])
    , Acronym "NAP" "Noise Abatement Procedures" (Sources [])
    , Acronym "NAS" "National Airspace System" (Sources [])
    , Acronym "NASC" "National AIS System Centre" (Sources [AIS])
    , Acronym "NAT" "NAVAID Training" (Sources [AIS])
    , Acronym "NAV" "Navigation" (Sources [])
    , Acronym "NAVAID" "Navigation Aid" (Sources [AIS])
    , Acronym "NAWD" "Non-acqueous Wet Developer" (Sources [AIS])
    , Acronym "NB" "Northbound" (Sources [AIS])
    , Acronym "NBFR" "Not Before" (Sources [])
    , Acronym "NC" "No Change" (Sources [AIS])
    , Acronym "NDB" "Non-directional Radio Beacon" (Sources [AIS])
    , Acronym "NDI" "Non-destructive inspection" (Sources [AIS])
    , Acronym "NDT" "Non-destructive testing" (Sources [AIS])
    , Acronym "NE" "Northeast" (Sources [AIS])
    , Acronym "NEG" "Negative, No. Permission not granted or, That is not correct" (Sources [CAR1988])
    , Acronym "NFRM" "Notice of Final Rule Making" (Sources [AIS])
    , Acronym "NG" "Gas Generator Speed" (Sources [AIS])
    , Acronym "NGT" "Night" (Sources [CASA])
    , Acronym "NIL" "None" (Sources [])
    , Acronym "NM" "Nautical Miles" (Sources [AIS])
    , Acronym "NML" "Normal" (Sources [AIS])
    , Acronym "NNE" "North North-East" (Sources [AIS])
    , Acronym "NNW" "North North-West" (Sources [AIS])
    , Acronym "NOF" "International NOTAM Office" (Sources [AIS])
    , Acronym "NOSIG" "No Significant Change" (Sources [AIS])
    , Acronym "NOTAM" "Notice To Airmen" (Sources [AIS])
    , Acronym "NOZ" "Normal Operating Zone" (Sources [AIP])
    , Acronym "NP" "Propeller Speed" (Sources [AIS])
    , Acronym "NPA" "Non-precision approach (procedures at aerodromes)" (Sources [AIS])
    , Acronym "NPC" "Notice of proposed change (consultation for amendment to a MOS)" (Sources [])
    , Acronym "NPRM" "Notice of proposed rule making" (Sources [AIS])
    , Acronym "NSC" "Nil Significant Cloud" (Sources [CAR1998])
    , Acronym "NTA" "No TAF Amendment" (Sources [CASA])
    , Acronym "NTL" "National" (Sources [AIS])
    , Acronym "NTS" "Negative Torque Sensing System" (Sources [AIS])
    , Acronym "NTSB" "National Transportation Safety Board (of the USA)" (Sources [AIS])
    , Acronym "NTZ" "No-transgression zone" (Sources [])
    , Acronym "NVD" "Night Vision Device" (Sources [])
    , Acronym "NVED" "Night Vision Enhancement Devices" (Sources [AIP,ICAO Nothing])
    , Acronym "NVET" "National vocational education and training" (Sources [])
    , Acronym "NVFR" "Night Visual Flight Rules" (Sources [])
    , Acronym "NVG" "Night Vision Goggles (by the MIL)" (Sources [CASRPart "66"])
    , Acronym "NVIS" "Night Vision Imaging Systems" (Sources [])
    , Acronym "NW" "North-West" (Sources [AIS])
    , Acronym "NXT" "Next" (Sources [])
    , Acronym "NZ" "New Zealand" (Sources [AIS])
    , Acronym "NZ CAA" "New Zealand Civil Aviation Authority" (Sources [AIS])
    , Acronym "NZS" "New Zealand Standard" (Sources [])
    , Acronym "O/R" "On Request" (Sources [])
    , Acronym "OAR" "Office of Airspace Regulation" (Sources [])
    , Acronym "OAT" "Outside Air Transport" (Sources [])
    , Acronym "OAT" "Outside Air Temperature" (Sources [CASA])
    , Acronym "OBPR" "Office of Best Practice Regulation" (Sources [])
    , Acronym "OBPR" "Office of Best Practice Regulation" (Sources [])
    , Acronym "OBS" "Omni Bearing Selector" (Sources [])
    , Acronym "OBS" "Observe, Observed, Observation" (Sources [])
    , Acronym "OBSC" "Obscure, Obscured, Obscuring" (Sources [])
    , Acronym "OBST" "Obstacle" (Sources [])
    , Acronym "OBSTR" "Obstruction" (Sources [])
    , Acronym "OC" "Operating Certificate" (Sources [])
    , Acronym "OCA" "Obstacle Clearing Altitude" (Sources [])
    , Acronym "OCA" "Oceanic Control Area" (Sources [])
    , Acronym "OCC" "Occulting (light)" (Sources [])
    , Acronym "OCH" "Obstacle Clearance Height" (Sources [])
    , Acronym "OCNL" "Occasional, Occasionally" (Sources [])
    , Acronym "OCTA" "Outside Control Area" (Sources [])
    , Acronym "OCTR" "Outside Control Zone" (Sources [])
    , Acronym "OEI" "One Engine Inoperative" (Sources [AIS])
    , Acronym "OEM" "Original Equipment Manufacturer" (Sources [])
    , Acronym "OFZ" "Obstacle Free Zone" (Sources [])
    , Acronym "OHD" "Overhead" (Sources [])
    , Acronym "OHS" "Occupation Health and Safety" (Sources [])
    , Acronym "OHSMS" "Occupational Health and Safety Management Systems" (Sources [])
    , Acronym "OIS" "Obstacle Identification Surface" (Sources [])
    , Acronym "OLC" "Office of Legal Counsel" (Sources [])
    , Acronym "OLDI" "On-line Data Interchange" (Sources [])
    , Acronym "OLS" "Obstacle Limitation Surface" (Sources [])
    , Acronym "OM" "Operations Manual" (Sources [])
    , Acronym "OM" "Outer Marker" (Sources [])
    , Acronym "OPA" "Opaque, white type of ice formation" (Sources [])
    , Acronym "OPC" "Office of Parliamentary Counsel" (Sources [])
    , Acronym "OPMET" "Operational Meteorological" (Sources [])
    , Acronym "OPN" "Operational Notification Message (message type designator)" (Sources [])
    , Acronym "OPN" "Open, Opening, Opened" (Sources [])
    , Acronym "OPR" "Operator, Operate, Operative, Operating, Operational" (Sources [])
    , Acronym "OPS" "Operations" (Sources [])
    , Acronym "OSIP" "Overhaul and Special Inspections Periods" (Sources [])
    , Acronym "OT" "Other Times" (Sources [CASA])
    , Acronym "OTAC" "Overseas Territories Aviation Circulars" (Sources [OtherSource "Air Safety Support International (UK)"])
    , Acronym "OTAR" "Overseas Territories Aviation Requirements" (Sources [OtherSource "Air Safety Support International (UK)"])
    , Acronym "OTLK" "Outlook (used in Sigmet messages for volcanic ash and tropical cyclones)" (Sources [OtherSource "Air Safety Support International (UK)"])
    , Acronym "OTP" "On Top" (Sources [OtherSource "Air Safety Support International (UK)"])
    , Acronym "OUBD" "Outboard" (Sources [])
    , Acronym "OVC" "Overcast" (Sources [])
    , Acronym "OW" "Over Water" (Sources [])
    , Acronym "P.." "Prohibited Area (followed by identification)" (Sources [])
    , Acronym "PA" "Precision Approach" (Sources [])
    , Acronym "PAL" "Pilot Activated Lighting" (Sources [AIS])
    , Acronym "PANS" "Procedures for Air Navigation Services" (Sources [])
    , Acronym "PANS-OPS" "Procedures for Air Navigation Services - Aircraft Operations (<em>ICAO Doc 8168 Vol I &amp; II</em>)" (Sources [AIS])
    , Acronym "PAPI" "Precision Approach Path Indicator" (Sources [AIS])
    , Acronym "PAR" "Precision Approach Radar" (Sources [ICAO Nothing])
    , Acronym "PARL" "Parallel" (Sources [AIS])
    , Acronym "PATC" "Precision Approach Terrain Chart (followed by name/title)" (Sources [AIS])
    , Acronym "PAX" "Passengers" (Sources [AIS])
    , Acronym "PBM" "Power Plant Build-Up Manual" (Sources [AIS])
    , Acronym "PC" "Personal Computer" (Sources [AIS])
    , Acronym "PCATD" "Personal Computer-based Aviation Training Device" (Sources [WATOG])
    , Acronym "PCD" "Proceed, Proceeding" (Sources [])
    , Acronym "PCL" "Pilot Controlled Lighting" (Sources [])
    , Acronym "PCN" "Pavement classification number" (Sources [AIS])
    , Acronym "PCT" "Practical consolidation training" (Sources [AIS])
    , Acronym "PDC" "Pre-Departure Clearance" (Sources [ICAO Nothing,AIP])
    , Acronym "PDO" "Product distribution organisation" (Sources [CASRPart "66"])
    , Acronym "PDOP" "Positional Dilution of Precision" (Sources [AIS])
    , Acronym "PDSE" "Pre-departure Service Check" (Sources [CASRPart "144"])
    , Acronym "PEC" "Pressure Error Correction" (Sources [])
    , Acronym "PERM" "Permanent" (Sources [])
    , Acronym "PFC" "Porous Friction Course" (Sources [AIS])
    , Acronym "PFR" "Preferred Route" (Sources [AIS])
    , Acronym "PH" "Public Holiday" (Sources [AIS])
    , Acronym "PIB" "Pre-flight information bulletin" (Sources [AIS])
    , Acronym "PIC" "Pilot-in-command" (Sources [AIS])
    , Acronym "PICUS" "Pilot-in-Command Under Supervision" (Sources [ICAO Nothing,AIP])
    , Acronym "PIFR" "Private IFR rating" (Sources [CAR1988])
    , Acronym "PILS" "Practice ILS" (Sources [])
    , Acronym "PIREP" "Pilot Reports" (Sources [CAR1988])
    , Acronym "PJE" "Parachute Jumping Exercise" (Sources [AIS])
    , Acronym "PL" "Ice Pellets" (Sources [WATOG])
    , Acronym "PLN" "Flight Plan" (Sources [AIS])
    , Acronym "PLVL" "Present Level" (Sources [CASA])
    , Acronym "PMP" "Primary Maintenance Process" (Sources [AIS])
    , Acronym "PN" "Prior Notice Required" (Sources [AIS])
    , Acronym "PNR" "Point of No Return" (Sources [WATOG])
    , Acronym "PO" "Dust Devils" (Sources [AIS])
    , Acronym "POB" "Persons on Board" (Sources [AIS])
    , Acronym "POH" "Pilot Operating Handbook" (Sources [])
    , Acronym "POSS" "Possible" (Sources [AIS])
    , Acronym "PPI" "Plan Position Indicator" (Sources [])
    , Acronym "PPL" "Private Pilot Licence" (Sources [AIS])
    , Acronym "PPR" "Prior Permission Required" (Sources [AIS])
    , Acronym "PPS" "Precise Positioning Service" (Sources [CAR1988])
    , Acronym "PPSN" "Present Position" (Sources [AIS])
    , Acronym "PRD" "Prohibited, Restricted and Danger Areas" (Sources [])
    , Acronym "PRFG" "Aerodrome Partially Covered by Fog (MET code)" (Sources [AIS])
    , Acronym "PRI" "Primary" (Sources [AIS])
    , Acronym "PRKG" "Parking" (Sources [AIS])
    , Acronym "PRM" "Precision Runway Monitoring" (Sources [AIS])
    , Acronym "PRM" "Precision runway monitoring" (Sources [AIS])
    , Acronym "PROB" "Probable, Probability" (Sources [AIS])
    , Acronym "PROC" "Procedure" (Sources [AIP])
    , Acronym "PROV" "Provisional" (Sources [AIS])
    , Acronym "PS" "Plus" (Sources [AIS])
    , Acronym "PSG" "Passing" (Sources [AIS])
    , Acronym "PSN" "Position" (Sources [AIS])
    , Acronym "PSP" "Pierced Steel Plank" (Sources [AIS])
    , Acronym "PSR" "Primary Surveillance Radar" (Sources [AIS])
    , Acronym "PSYS" "Pressure System(s)" (Sources [AIS])
    , Acronym "PTBL" "Portable" (Sources [AIS])
    , Acronym "PTN" "Procedure Turn" (Sources [AIS])
    , Acronym "PTT" "Push To Talk" (Sources [AIS])
    , Acronym "PVT" "Private" (Sources [AIS])
    , Acronym "PWR" "Power" (Sources [])
    , Acronym "QDM" "Magnetic Heading (zero wind)" (Sources [AIS])
    , Acronym "QDR" "Magnetic Bearing" (Sources [AIS])
    , Acronym "QEC" "Quick Engine Change Unit" (Sources [AIP])
    , Acronym "QFE" "An altimeter set to QFE will read zero when the aircraft is on the runway" (Sources [AIP])
    , Acronym "QMS" "Quality Management System" (Sources [WATOG])
    , Acronym "QNH" "Altimeter subscale setting to obtain elevation or altitude" (Sources [])
    , Acronym "QTE" "True Bearing" (Sources [])
    , Acronym "QTG" "Qualification test guide" (Sources [AIS])
    , Acronym "QUAD" "Quadrant" (Sources [AIP])
    , Acronym "R" "Red" (Sources [])
    , Acronym "R" "Right (runway system identification)" (Sources [AIS])
    , Acronym "R...." "Restricted Area (followed by number)" (Sources [AIS])
    , Acronym "R/T" "Radio Telephone" (Sources [AIS])
    , Acronym "RA" "Rain" (Sources [AIS])
    , Acronym "RA-Aus" "Recreational Aviation Australia" (Sources [])
    , Acronym "RAAA" "Recreational Aviation Association of Australia" (Sources [AIS])
    , Acronym "RAAO" "Recreational Aviation Administrative Organisation" (Sources [])
    , Acronym "RAC" "Rules of the Air and Air Traffic Services" (Sources [])
    , Acronym "RAD" "Radius" (Sources [])
    , Acronym "RAeS" "Royal Aeronautical Society" (Sources [AIS])
    , Acronym "RAFC" "Regional Area Forecast Centre" (Sources [AIS])
    , Acronym "RAG" "Ragged" (Sources [])
    , Acronym "RAG" "Runway Arresting Gear" (Sources [AIS])
    , Acronym "RAI" "Runway Alignment Indicator" (Sources [AIS])
    , Acronym "RAIM" "Receiver Autonomous Integrity Monitoring" (Sources [AIS])
    , Acronym "RAM" "Repair and Maintenance" (Sources [AIS])
    , Acronym "RAPAC" "Regional Airspace Users Advisory Committee" (Sources [])
    , Acronym "RAPIC" "Radar Picture (MET)" (Sources [])
    , Acronym "RAS" "Radar Advisory Service" (Sources [])
    , Acronym "RASF" "Regional Aviation Safety Forum" (Sources [])
    , Acronym "RAT" "RAM Air Turbine" (Sources [AIS])
    , Acronym "RCA" "Reach Cruising Altitude," (Sources [AIS])
    , Acronym "RCA" "Request For Corrective Action" (Sources [])
    , Acronym "RCC" "Rescue Coordination Centre" (Sources [AIS])
    , Acronym "RCH" "Reach, Reaching" (Sources [AIS])
    , Acronym "RCL" "Runway Centre Line" (Sources [AIS])
    , Acronym "RCLL" "Runway Centre Line Lights" (Sources [AIS])
    , Acronym "RCLM" "Runway Centre Line Marking" (Sources [AIS])
    , Acronym "RDL" "Radial" (Sources [AIS])
    , Acronym "RDO" "Radio" (Sources [AIS])
    , Acronym "RE..." "Recent (used to qualify weather phenomena, eg RERA = recent rain)" (Sources [CASA])
    , Acronym "REC" "Receive, Receiver, Received" (Sources [AIS])
    , Acronym "REDL" "Runway Edge Lights" (Sources [AIS])
    , Acronym "REF" "Reference to... Refer to..." (Sources [AIS])
    , Acronym "REG" "Registration" (Sources [AIS])
    , Acronym "RENL" "Runway End Lights" (Sources [AIS])
    , Acronym "REP" "Report, Reported, Reporting, Reporting Point" (Sources [AIS])
    , Acronym "REQ" "Request, Requested" (Sources [AIS])
    , Acronym "RERTE" "Re-route" (Sources [AIS])
    , Acronym "RES" "Reserve Fuel" (Sources [AIS])
    , Acronym "RESA" "Runway end safety area" (Sources [AIS])
    , Acronym "RESTR" "Restrictions" (Sources [AIS])
    , Acronym "REV" "Review" (Sources [ICAO Nothing,AIP])
    , Acronym "RFACA" "Royal Federation of Aero Clubs of Australia" (Sources [AIS])
    , Acronym "RFC" "Request for change" (Sources [AIS])
    , Acronym "RFC" "Regional Forecasting Centre (Met)" (Sources [])
    , Acronym "RFFS" "Rescue and Fire Fighting Services" (Sources [])
    , Acronym "RH" "Radio Height" (Sources [AIS])
    , Acronym "RHC" "Right-hand Circuit" (Sources [CASA])
    , Acronym "RIF" "Reclearance in Flight" (Sources [AIS])
    , Acronym "RIFTO" "Restricted Instrument Flight Take-off" (Sources [AIS])
    , Acronym "RIS" "Regulation Impact Statement" (Sources [OBPR])
    , Acronym "RIS" "Radar information service" (Sources [])
    , Acronym "RL" "Report Leaving" (Sources [ORR])
    , Acronym "RLA" "Relay to" (Sources [AIP,ICAO Nothing])
    , Acronym "RLLS" "Runway Lead-in Lighting" (Sources [AIS])
    , Acronym "RMIT" "Royal Melbourne Institute of Technology" (Sources [AIS])
    , Acronym "RMK" "Remark(s)" (Sources [AIS])
    , Acronym "RMS" "Root Mean Square" (Sources [])
    , Acronym "RNAV" "Area navigation" (Sources [AIS])
    , Acronym "RNP" "Required navigation performance" (Sources [])
    , Acronym "RO" "Registered operator" (Sources [AIP])
    , Acronym "ROBEX" "Regional OPMET Bulletin Exchanges" (Sources [])
    , Acronym "ROC" "Rate of Climb" (Sources [CASRPart "43"])
    , Acronym "ROD" "Rate of Descent" (Sources [AIS])
    , Acronym "ROFOR" "Route Forecast (in aeronautical meteorological code)" (Sources [AIS])
    , Acronym "RPA" "Rules and practices for aerodromes" (Sources [AIS])
    , Acronym "RPI" "Radar Position Indicator" (Sources [AIS])
    , Acronym "RPI" "Regulatory Performance Indicator" (Sources [CAR1988])
    , Acronym "RPI" "Runway Point of Intercept" (Sources [AIS])
    , Acronym "RPL" "Recognition of prior learning" (Sources [CAR1988])
    , Acronym "RPM" "Revolutions Per Minute" (Sources [AIS])
    , Acronym "RPT" "Regular public transport" (Sources [CASRPart "66"])
    , Acronym "RQ" "Require(d)" (Sources [])
    , Acronym "RQMNTS" "Requirements" (Sources [CAR1988])
    , Acronym "RR" "Report Reaching" (Sources [AIS])
    , Acronym "RRM" "Routine Reportable Matters" (Sources [AIS])
    , Acronym "RSC" "Rescue Sub-Centre" (Sources [CASA])
    , Acronym "RSCD" "Runway Surface Condition" (Sources [CASA])
    , Acronym "RSP" "Responder Beacon" (Sources [AIS])
    , Acronym "RSR" "En route Surveillance Radar" (Sources [AIS])
    , Acronym "RTB" "Return to Base" (Sources [AIS])
    , Acronym "RTCA" "Radio Technical Commission for Aeronautics" (Sources [CASA])
    , Acronym "RTE" "Route" (Sources [])
    , Acronym "RTF" "Radio Telephone" (Sources [])
    , Acronym "RTHL" "Runway Threshold Light(s)" (Sources [AIS])
    , Acronym "RTIL" "Runway Threshold Identification Lights" (Sources [AIS])
    , Acronym "RTN" "Return, Returned, Returning" (Sources [AIS])
    , Acronym "RTO" "Rejected take-off" (Sources [AIS])
    , Acronym "RTO" "Registered training organisation" (Sources [AIS])
    , Acronym "RTS" "Return to Service" (Sources [AIP])
    , Acronym "RTZL" "Runway Touchdown Zone Light(s)" (Sources [CASRPart "147"])
    , Acronym "RVR" "Runway visual range" (Sources [AIS])
    , Acronym "RVSM" "Reduced Vertical Separation Minimum" (Sources [AIS])
    , Acronym "RWS" "Runway Strip" (Sources [AIP,ICAO Nothing])
    , Acronym "RWY" "Runway" (Sources [ICAO Nothing,CAR1988])
    , Acronym "S" "South, South Latitude" (Sources [AIS])
    , Acronym "S-I" "Straight-In" (Sources [AIS])
    , Acronym "S/E" "Single-engine" (Sources [AIP])
    , Acronym "SA" "Sand" (Sources [WATOG])
    , Acronym "SA" "Selective Availability" (Sources [])
    , Acronym "SA" "Situation Awareness" (Sources [AIS])
    , Acronym "SAAA" "Sport Aircraft Association of Australia" (Sources [])
    , Acronym "SAL" "Supplementary Airline Licence" (Sources [])
    , Acronym "SALR" "Saturated Adiabatic Lapse Rate" (Sources [])
    , Acronym "SALS" "Simple Approach Lighting System" (Sources [AIS])
    , Acronym "SAR" "Search and Rescue" (Sources [])
    , Acronym "SARPs" "Standards and Recommended Practices" (Sources [ICAO Nothing])
    , Acronym "SARTIME" "Time search action required" (Sources [AIS])
    , Acronym "SARWATCH" "Search and Rescue Watch" (Sources [ICAO Nothing])
    , Acronym "SATCOM" "Satellite Communication" (Sources [])
    , Acronym "SB" "Service Bulletin" (Sources [])
    , Acronym "SB" "Southbound" (Sources [AIS])
    , Acronym "SBAS" "Satellite Based Augmentation System" (Sources [AIS])
    , Acronym "SC" "Stratocumulus" (Sources [AIS])
    , Acronym "SCC" "Standards Consultative Committee" (Sources [])
    , Acronym "SCP" "Safety Critical Personnel" (Sources [AIS])
    , Acronym "SCT" "Scattered (meteorological)" (Sources [CASA])
    , Acronym "SDBY" "Standby" (Sources [])
    , Acronym "SDC" "Standard Departure Clearance" (Sources [AIS])
    , Acronym "SDR" "Service difficulty report" (Sources [AIS])
    , Acronym "SE" "South East" (Sources [AIS])
    , Acronym "SEA" "Sea (used in connection with sea-surface temperature and state of the sea)" (Sources [CAR1998])
    , Acronym "SEACO" "Single engine aircraft only" (Sources [AIS])
    , Acronym "SEC" "Seconds" (Sources [AIS])
    , Acronym "SECN" "Section" (Sources [])
    , Acronym "SECT" "Sector" (Sources [AIS])
    , Acronym "SELCAL" "Selective Calling System" (Sources [AIS])
    , Acronym "SER" "Service, Servicing, Served" (Sources [AIS])
    , Acronym "SEV" "Severe (used eg to qualify icing and turbulence report)" (Sources [AIS])
    , Acronym "SFC" "Surface" (Sources [AIS])
    , Acronym "SFL" "Sequenced Flashing Lights" (Sources [AIS])
    , Acronym "SG" "Snow Grains" (Sources [AIS])
    , Acronym "SH..." "Showers (followed by RA=rain, SN=snow, PL=ice pellets, GR=hail, GS=small hail and/or snow pellets or combinations thereof, eg, SHRASN = showers of rain and snow)" (Sources [AIS])
    , Acronym "SHF" "Super High Frequency (3,000 to 30,000 MHZ)" (Sources [AIS])
    , Acronym "SHP" "Shaft Horse Power" (Sources [AIS])
    , Acronym "SID" "Standard instrument departure" (Sources [AIS])
    , Acronym "SIF" "Selective Identification" (Sources [])
    , Acronym "SIG" "Significant" (Sources [ICAO Nothing,AIP])
    , Acronym "SIGMET" "Information concerning en route weather phenomena which may affect the safety of aircraft operations" (Sources [AIS])
    , Acronym "SIL" "Service Information Letter" (Sources [AIS])
    , Acronym "SIMUL" "Simultaneous, or Simultaneously" (Sources [AIS])
    , Acronym "SKC" "Sky Clear" (Sources [])
    , Acronym "SKED" "Schedule, Scheduled" (Sources [AIS])
    , Acronym "SL" "Service Letter" (Sources [AIS])
    , Acronym "SLP" "Speed Limiting Point" (Sources [AIS])
    , Acronym "SLW" "Slow, Slowly" (Sources [])
    , Acronym "SM" "Safety Manager" (Sources [AIS])
    , Acronym "SMC" "Surface Movement Control" (Sources [AIS])
    , Acronym "SMR" "Surface Movement Radar" (Sources [])
    , Acronym "SMS" "Safety management system" (Sources [AIS])
    , Acronym "SN" "Snow" (Sources [AIS])
    , Acronym "SNOWTAM" "A special series NOTAM notifying the presence or removal of hazardous conditions due to snow, ice, slush or standing water associated with snow, slush and ice on the movement area" (Sources [CAR1998])
    , Acronym "SOC" "Start of Climb" (Sources [AIS])
    , Acronym "SOE" "Schedule of experience" (Sources [AIS])
    , Acronym "SOM (SoM)" "System of Maintenance" (Sources [AIS])
    , Acronym "SOPs" "Standard Operating Procedures" (Sources [CAR1988])
    , Acronym "SOR" "Summary of responses" (Sources [CAR1998])
    , Acronym "SOT" "Start of TORA (take-off)" (Sources [])
    , Acronym "SP" "Single Pilot" (Sources [CASA])
    , Acronym "SPA" "Sport Aviation" (Sources [AIS])
    , Acronym "SPECI" "Aviation Special Weather (in aeronautical meteorological code)" (Sources [AIS])
    , Acronym "SPFIB" "Specific Preflight Information Bulletin" (Sources [AIS])
    , Acronym "SPOT" "Spotwind" (Sources [AIS])
    , Acronym "SPS" "Standard Positioning Service" (Sources [AIS])
    , Acronym "SQ" "Squall" (Sources [AIS])
    , Acronym "SR" "Sunrise" (Sources [])
    , Acronym "SRB" "Safety Review Board" (Sources [AIS])
    , Acronym "SRD" "Standard Radar Departure" (Sources [AIS])
    , Acronym "SRG" "Short Range" (Sources [])
    , Acronym "SRM" "Structural Repair Manual" (Sources [AIS])
    , Acronym "SRR" "Search and Rescue Region" (Sources [AIS])
    , Acronym "SRY" "Secondary" (Sources [WATOG])
    , Acronym "SS" "Sandstorm" (Sources [AIS])
    , Acronym "SS" "Sunset" (Sources [AIS])
    , Acronym "SSB" "Single Sideband" (Sources [AIS])
    , Acronym "SSCRO" "Senate Standing Committee on Regulations and Ordinances" (Sources [AIS])
    , Acronym "SSE" "South South-East" (Sources [AIS])
    , Acronym "SSI" "Structural Significant Item" (Sources [])
    , Acronym "SSM" "System Schematics Manual" (Sources [AIS])
    , Acronym "SSR" "Secondary Surveillance Radar" (Sources [WATOG])
    , Acronym "SST" "Supersonic Transport" (Sources [WATOG])
    , Acronym "SSW" "South South-West" (Sources [AIS])
    , Acronym "ST" "Stratus" (Sources [AIS])
    , Acronym "STA" "Straight in Approach" (Sources [AIS])
    , Acronym "STAR" "Standard Arrival Route" (Sources [AIS])
    , Acronym "STAR" "Standard instrumental arrival" (Sources [AIS])
    , Acronym "STARs" "Standard terminal arrival routes" (Sources [AIP])
    , Acronym "STC" "Supplemental Type Certificate" (Sources [ICAO Nothing])
    , Acronym "STD" "Synthetic training device" (Sources [])
    , Acronym "STD" "Standard" (Sources [CASRPart "21"])
    , Acronym "STF" "Stratiform" (Sources [CASRPart "60"])
    , Acronym "STN" "Station" (Sources [AIS])
    , Acronym "STNR" "Stationary" (Sources [AIS])
    , Acronym "STODA" "Supplementary Take-off Distance" (Sources [AIS])
    , Acronym "STOL" "Short Take-off and Landing" (Sources [AIS])
    , Acronym "STS" "Status" (Sources [AIS])
    , Acronym "STWL" "Stopway Light(s)" (Sources [AIS])
    , Acronym "SUBJ" "Subject to" (Sources [AIS])
    , Acronym "SUP" "Supplement (AIP Supplement)" (Sources [AIS])
    , Acronym "SUPPS" "Regional Supplementary Procedures" (Sources [AIS])
    , Acronym "SVCBL" "Serviceable" (Sources [AIS])
    , Acronym "SVY" "Survey Operations" (Sources [AIS])
    , Acronym "SW" "South-West" (Sources [AIS])
    , Acronym "SWS" "Soft Wet Surface" (Sources [AIS])
    , Acronym "SWY" "Stopway" (Sources [AIS])
    , Acronym "T" "Temperature" (Sources [AIS])
    , Acronym "T-VASIS" "'T'Visual Approach Slope Indicator System (pronounced 'TEE-VAR-SIS')" (Sources [AIS])
    , Acronym "TA" "Transition Altitude" (Sources [AIS])
    , Acronym "TA" "Traffic advisory" (Sources [AIS])
    , Acronym "TAAATS" "The Australian Advanced Air Traffic System" (Sources [AIS])
    , Acronym "TAAM" "Airservices Australia's Total Airspace Airport and Aerodrome Modeller" (Sources [ICAO Nothing,AIP])
    , Acronym "TAC" "Terminal Area Chart" (Sources [])
    , Acronym "TACAN" "Tactical Air Navigation Aid" (Sources [AIS])
    , Acronym "TAF" "Aerodrome Forecast" (Sources [AIS])
    , Acronym "TAF" "Terminal Area Forecast" (Sources [AIS])
    , Acronym "TAIL" "Tailwind" (Sources [AIS])
    , Acronym "TAR" "Terminal Area Surveillance Area" (Sources [])
    , Acronym "TAS" "True Airspeed" (Sources [AIS])
    , Acronym "TAT" "Terminal Area Thunderstorm Service (meteorological term)" (Sources [AIS])
    , Acronym "TAWS" "Terrain awareness and warning system" (Sources [AIS])
    , Acronym "TAWS-B+ system" "A terrain awareness and warning system that is equipped with a visual display and complies with the requirements for Class B equipment expressed in TSO-C151, TSO-C151a or TSO-C151b." (Sources [AIS])
    , Acronym "TAX" "Taxiing, Taxi" (Sources [OtherSource "CAO 20.18"])
    , Acronym "TBA" "To be advised" (Sources [OtherSource "CAO Part 20, Section 20.18, Issue 9"])
    , Acronym "TBO" "Time Between Overhauls" (Sources [AIS])
    , Acronym "TC" "Type Certificate" (Sources [AIS])
    , Acronym "TC" "Tropical Cyclone" (Sources [WATOG])
    , Acronym "TCAC" "Tropical Cyclone Advisory Centre" (Sources [AIS])
    , Acronym "TCAS" "Traffic alert and collision avoidance system" (Sources [CASA])
    , Acronym "TCDS" "Type certificate data sheet" (Sources [])
    , Acronym "TCH" "Threshold Crossing Height" (Sources [ICAO Nothing])
    , Acronym "TCO" "Training and Checking Organisation" (Sources [CASRPart "21"])
    , Acronym "TCTA" "Trans-continental Control Area" (Sources [AIS])
    , Acronym "TCU" "Towering Cumulus (met)" (Sources [])
    , Acronym "TDO" "Tornado" (Sources [AIS])
    , Acronym "TDZ" "Touchdown Zone" (Sources [AIS])
    , Acronym "TECR" "Technical Reason" (Sources [AIS])
    , Acronym "TEL" "Telephone" (Sources [AIS])
    , Acronym "TEM" "(Illustrated) Tool And Equipment Manual" (Sources [AIS])
    , Acronym "TEM" "Threat and Error Management" (Sources [AIS])
    , Acronym "TEMPO" "Temporary, Temporarily (meteorologically)" (Sources [WATOG])
    , Acronym "TERPs" "Terminal and En-route procedures" (Sources [])
    , Acronym "TFC" "Traffic" (Sources [AIS])
    , Acronym "TFR" "Terrain Following Radar (by the MIL)" (Sources [AIS])
    , Acronym "TGL" "Touch & Go Landing" (Sources [AIS])
    , Acronym "TGS" "Taxiing Guidance System" (Sources [AIS])
    , Acronym "THR" "Threshold" (Sources [AIS])
    , Acronym "THRU" "Through" (Sources [AIS])
    , Acronym "TIBA" "Traffic Information Broadcasts by Aircraft" (Sources [AIS])
    , Acronym "TIL" "Until" (Sources [AIS])
    , Acronym "TIP" "Until Past (place)" (Sources [AIS])
    , Acronym "TIS" "Time in service" (Sources [AIS])
    , Acronym "TKOF" "Take-off" (Sources [AIS])
    , Acronym "TLOF" "Touchdown and lift-off area" (Sources [])
    , Acronym "TLS" "Transponder Landing System" (Sources [AIS])
    , Acronym "TLW" "Time Limited WIP (work in progress)" (Sources [ICAO Nothing])
    , Acronym "TMA" "Terminal Control Area" (Sources [])
    , Acronym "TMG" "Track Made Good" (Sources [AIS])
    , Acronym "TNA" "Training Needs Analysis" (Sources [AIS])
    , Acronym "TNA" "Turn Altitude" (Sources [])
    , Acronym "TNH" "Turn Height" (Sources [])
    , Acronym "TNS" "Transitional Surface" (Sources [AIS])
    , Acronym "TOC" "Top of Climb" (Sources [AIS])
    , Acronym "TODA" "Take-off distance available" (Sources [AIS])
    , Acronym "TOP" "Cloud Top" (Sources [AIS])
    , Acronym "TORA" "Take-off run available" (Sources [ICAO Nothing])
    , Acronym "TOT" "Turbine Outlet Temperature" (Sources [AIS])
    , Acronym "TP" "Turning Point" (Sources [ICAO Nothing])
    , Acronym "TR" "Track" (Sources [])
    , Acronym "TRA" "Temporary Reserved Airspace" (Sources [AIS])
    , Acronym "TRAN" "Transition" (Sources [AIS])
    , Acronym "TRANS" "Transmits, Transmitter" (Sources [AIS])
    , Acronym "Trike" "A manned, powered hang-glider" (Sources [AIS])
    , Acronym "TRL" "Transition Level" (Sources [AIS])
    , Acronym "TROP" "Tropopause" (Sources [])
    , Acronym "TS..." "Thunderstorm (followed by RA=rain, SN=snow, PE=ice pellets, GR=hail, GS=small hail and/or snow pellets or combinations thereof, eg TSRASN = thunderstorm with rain and snow)" (Sources [AIS])
    , Acronym "TSI" "Time Since Installation" (Sources [AIS])
    , Acronym "TSO" "Technical Standard Order" (Sources [AIS])
    , Acronym "TSO" "Time Since Overhaul" (Sources [WATOG])
    , Acronym "TTF" "Trend Type Forecast" (Sources [])
    , Acronym "TTMRA" "Trans Tasman Mutual Recognition Agreement" (Sources [WATOG])
    , Acronym "TURB" "Turbulence" (Sources [])
    , Acronym "TWR" "Aerodrome Control Tower, Aerodrome Control" (Sources [AIS])
    , Acronym "TWY" "Taxiway" (Sources [AIS])
    , Acronym "TWYL" "Taxiway Link" (Sources [AIS])
    , Acronym "TYP" "Type of Aircraft" (Sources [AIS])
    , Acronym "TYPH" "Typhoon" (Sources [AIS])
    , Acronym "U/S" "Unserviceable" (Sources [AIS])
    , Acronym "UAB" "Until Advised By" (Sources [AIS])
    , Acronym "UAV" "Unmanned aerial vehicles" (Sources [AIS])
    , Acronym "UDF" "UHF Direction Finding Stations" (Sources [AIS])
    , Acronym "UFIT" "Uncontrolled Flight Into Terrain" (Sources [CASRPart "101"])
    , Acronym "UFN" "Until Further Notice" (Sources [AIS])
    , Acronym "UHDT" "Unable Higher Due Traffic" (Sources [])
    , Acronym "UHF" "Ultra High Frequency (300 to 3,000 MHZ)" (Sources [AIS])
    , Acronym "UIR" "Upper Flight Information Region" (Sources [AIS])
    , Acronym "UK" "United Kingdom" (Sources [AIS])
    , Acronym "UL" "Upper Limits" (Sources [AIS])
    , Acronym "UNA" "Unable" (Sources [])
    , Acronym "UNAP" "Unable to Approve" (Sources [AIS])
    , Acronym "UNICOM" "Universal Communications" (Sources [AIS])
    , Acronym "UNL" "Unlimited" (Sources [AIS])
    , Acronym "UNLC" "Unlicensed" (Sources [])
    , Acronym "UNREL" "Unreliable" (Sources [AIS])
    , Acronym "US FAR" "Federal Aviation Regulations (of the USA)" (Sources [AIS])
    , Acronym "USA" "United States of America" (Sources [])
    , Acronym "UTA" "Upper Control Area" (Sources [])
    , Acronym "UTC" "Coordinated Universal Time" (Sources [])
    , Acronym "V" "Velocity" (Sources [AIS])
    , Acronym "V1" "Take-off Decision Speed" (Sources [AIS])
    , Acronym "V2" "Take-off Safety Speed (Applicable to Larger Multi-engine Aircraft)" (Sources [])
    , Acronym "VA" "Volcanic Ash" (Sources [])
    , Acronym "VA" "Maximum Manoeuvring Speed" (Sources [])
    , Acronym "VAA-H" "Visual Approach Area - Helicopter" (Sources [AIS])
    , Acronym "VAAC" "Volcanic Ash Advisory Centre" (Sources [])
    , Acronym "VAC" "Visual Approach Chart (followed by name/title)" (Sources [])
    , Acronym "VAL" "In Valleys" (Sources [])
    , Acronym "VAR" "Magnetic Variation" (Sources [AIS])
    , Acronym "VASIS" "Visual Approach Slope Indicator System" (Sources [AIS])
    , Acronym "VC" "Vicinity of the aerodrome (followed by FG=fog, FC=funnel cloud, PO=dust/sand whirls, BLDU=blowing dust, BLSA=blowing sand or BLSN=blowing snow; eg, VCFG=vicinity fog" (Sources [AIS])
    , Acronym "VCY" "Vicinity" (Sources [AIS])
    , Acronym "VDF" "VHF Direction Finding Station" (Sources [AIS])
    , Acronym "VEC" "Visual En-route Chart" (Sources [AIS])
    , Acronym "VER" "Vertical" (Sources [AIS])
    , Acronym "VFE" "Flap Extension Speed" (Sources [AIS])
    , Acronym "VFR" "Visual flight rules" (Sources [AIS])
    , Acronym "VHF" "Very High Frequency (30 to 300 MHZ)" (Sources [])
    , Acronym "VHFCOM" "Very High Frequency Communications" (Sources [])
    , Acronym "VIA" "By way of..." (Sources [AIS])
    , Acronym "VIMD" "Maximum Drag Speed" (Sources [])
    , Acronym "VIP" "Very Important Person" (Sources [AIS])
    , Acronym "VIS" "Visibility" (Sources [])
    , Acronym "VLE" "Maximum Speed with Landing Gear Extended" (Sources [AIS])
    , Acronym "VLF" "Very Low Frequency (3 to 30 KHZ)" (Sources [AIS])
    , Acronym "VLJ" "Very Light Jet" (Sources [])
    , Acronym "VLO" "Landing Gear Operating" (Sources [AIS])
    , Acronym "VLO2" "Landing Gear Operation Down" (Sources [])
    , Acronym "VLR" "Very Long Range" (Sources [])
    , Acronym "VMAN" "Visual Manoeuvre Speed" (Sources [])
    , Acronym "VMC" "Visual Meteorological Conditions" (Sources [AIS])
    , Acronym "VMC" "Minimum Control Speed" (Sources [])
    , Acronym "VMCA" "Minimum Control Airspeed Airborne (Red line speed)" (Sources [AIS])
    , Acronym "VMCG" "Minimum Control Airspeed on the Ground" (Sources [])
    , Acronym "VMO" "Maximum Structural Cruising Speed" (Sources [])
    , Acronym "VNAV" "Vertical Navigation" (Sources [])
    , Acronym "VNE" "Never Exceed Speed" (Sources [])
    , Acronym "VNO" "Normal Operating Speed" (Sources [ICAO Nothing])
    , Acronym "VOLMET" "Meteorological Information for Aircraft in Flight" (Sources [ICAO Nothing])
    , Acronym "VOR" "VHF Omni-directional Radio Range (OMNI)" (Sources [])
    , Acronym "VP" "Variable Pitch Propellers" (Sources [AIS])
    , Acronym "VR" "The speed at which the aircraft is rotated to lift off from the runway" (Sources [AIS])
    , Acronym "VRB" "Variable" (Sources [])
    , Acronym "VSI" "Vertical Speed Indicator" (Sources [])
    , Acronym "VSI" "Clean Stall Speed" (Sources [AIS])
    , Acronym "VSL" "Vertical speed limit" (Sources [])
    , Acronym "VSO" "Stalling speed, minimum steady flight speed in the landing configuration" (Sources [])
    , Acronym "VSO" "Stall speed with undercarriage and flap selected" (Sources [ICAO Nothing])
    , Acronym "VSSE" "Safe single-engine Speed" (Sources [CAR1998])
    , Acronym "VTC" "Visual Terminal Chart" (Sources [])
    , Acronym "VTOL" "Vertical take-off and landing" (Sources [])
    , Acronym "VTOSS" "Take-off Safely Speed" (Sources [AIS])
    , Acronym "VX" "Best Angle of Climb Speed" (Sources [ICAO Nothing])
    , Acronym "VXSE" "Best Single-engine Angle of Climb Speed" (Sources [])
    , Acronym "Vy" "Best Rate of Climb Speed" (Sources [])
    , Acronym "VYSE" "Best Single-engine Rate of Climb Speed (Blue line speed)" (Sources [])
    , Acronym "W" "Watt" (Sources [])
    , Acronym "W" "West, West Longitude" (Sources [])
    , Acronym "W" "White" (Sources [])
    , Acronym "W/V" "Wind Velocity" (Sources [AIS])
    , Acronym "WAAS" "Wide Area Augmentation System" (Sources [AIS])
    , Acronym "WAC" "World Aeronautical Chart ICAO 1:1,000,000 (followed by name/title)" (Sources [])
    , Acronym "WAFC" "World Area Forecast Centre" (Sources [])
    , Acronym "WAFS" "World Area Forecast System" (Sources [AIS])
    , Acronym "WATIR" "Weather and Terminal Information Reciter" (Sources [AIS])
    , Acronym "WATOG" "World Airlines Technical Operations Glossary" (Sources [])
    , Acronym "WB" "Westbound" (Sources [AIS])
    , Acronym "WBM" "Weight And Balance Manual" (Sources [])
    , Acronym "WDI" "Wind Direction Indicator" (Sources [AIS])
    , Acronym "WDSPR" "Widespread" (Sources [WATOG])
    , Acronym "WED" "Wednesday" (Sources [AIS])
    , Acronym "WEF" "With Effect From, Effective From" (Sources [AIS])
    , Acronym "WGS-84" "World Geodetic System 1984" (Sources [AIS])
    , Acronym "WI" "Within" (Sources [AIS])
    , Acronym "WID" "Width" (Sources [AIS])
    , Acronym "WIE" "With Immediate Effect, Effective Immediately" (Sources [AIS])
    , Acronym "WILCO" "Will Comply" (Sources [AIS])
    , Acronym "WIND" "Wind (used in connection with direction and speed) WINTEM Forecast upper wind and temperature at specified points (in aeronautical met code)" (Sources [AIS])
    , Acronym "WIP" "Work in Progress" (Sources [AIS])
    , Acronym "WKN" "Weaken, Weakening" (Sources [AIS])
    , Acronym "WM" "Wiring Manual" (Sources [AIS])
    , Acronym "WMO" "World Meteorological Organisation" (Sources [AIS])
    , Acronym "WNW" "West North-West" (Sources [WATOG])
    , Acronym "WO" "Without" (Sources [])
    , Acronym "WPT" "Way-point" (Sources [AIS])
    , Acronym "WRNG" "Warning" (Sources [AIS])
    , Acronym "WS" "Wind Shear" (Sources [AIS])
    , Acronym "WSW" "West South-West" (Sources [AIS])
    , Acronym "WT" "Weight" (Sources [AIS])
    , Acronym "WTSPT" "Water Spout" (Sources [AIS])
    , Acronym "WWW" "World Wide Web" (Sources [AIS])
    , Acronym "WX" "Weather" (Sources [AIS])
    , Acronym "X" "Cross" (Sources [AIS])
    , Acronym "XBAR" "Crossbar (of approach lighting system)" (Sources [AIS])
    , Acronym "XNG" "Crossing" (Sources [AIS])
    , Acronym "XS" "Atmospherics" (Sources [AIS])
    , Acronym "XSEC" "Extra Section" (Sources [AIS])
    , Acronym "Y" "Yellow" (Sources [AIS])
    , Acronym "YCZ" "Yellow Caution Zone" (Sources [WATOG])
    , Acronym "YR" "Your/s" (Sources [AIS])
    , Acronym "Z" "Coordinated Universal Time (in meteorological messages)" (Sources [AIS])
    ]
